<?php

/**
 * The public-facing functionality of the plugin.
 *`
 * @link       https://pataa.com
 * @since      1.0.0
 *
 * @package    Addressautofill
 * @subpackage Addressautofill/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Addressautofill
 * @subpackage Addressautofill/public
 * @author     Sunil Ramsinghani <s.ramsinghani@pataa.com>
 */

 class Addressautofill_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		//add_action('woocommerce_checkout_update_order_meta','addMetatoOrders', 10, 2);
		add_action('woocommerce_checkout_update_order_meta',array($this,'addMetatoOrders'), 10, 2);

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Addressautofill_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Addressautofill_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/addressautofill-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Addressautofill_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Addressautofill_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		 //ADDED FOR DEBUGGING PURPOSE BY RAHUL ON 21-04-23
		//$t=time();
		//echo($t . "<br>");

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/addressautofill-public.js', array( 'jquery' ), $this->version, false );
		$api_key = get_option("settings_page_example_setting");
		$merchant_id = get_option("settings_page_example_setting_1");

		if(get_option("demo-radio")=='1'){
			$type="services";
		}
		else{
			$type="product";
		}
		$scriptData = array(
        'api_key' => $api_key,
		'merchant_id' => $merchant_id,
		'type'=>$type,
    	);
		wp_localize_script($this->plugin_name, 'my_key', $scriptData);
		wp_enqueue_script( 'custom', 'https://assets.pataa.com/create-pataa-minified/create-pataa.js', array( 'jquery' ), $this->version, false );
		
		

	}


	public function custom_shop_order_column($columns)
	{
		$reordered_columns = array();
	
		// Inserting columns to a specific location
		foreach( $columns as $key => $column){
			$reordered_columns[$key] = $column;
			if( $key ==  'order_status' ){
				// Inserting after "Status" column
				$reordered_columns['pataacode'] = __( 'Pataa Code','theme_domain');
				$reordered_columns['dlink'] = __( 'Pataa Link','theme_domain');
			}
		}
		return $reordered_columns;
	}


	public function custom_orders_list_column_content( $column, $post_id )
	{
		global $post, $the_order;
		global $allowedposttags;
$allowed_atts = array(
	'align'      => array(),
	'class'      => array(),
	'type'       => array(),
	'id'         => array(),
	'dir'        => array(),
	'lang'       => array(),
	'style'      => array(),
	'xml:lang'   => array(),
	'src'        => array(),
	'alt'        => array(),
	'href'       => array(),
	'rel'        => array(),
	'rev'        => array(),
	'target'     => array(),
	'novalidate' => array(),
	'type'       => array(),
	'value'      => array(),
	'name'       => array(),
	'tabindex'   => array(),
	'action'     => array(),
	'method'     => array(),
	'for'        => array(),
	'width'      => array(),
	'height'     => array(),
	'data'       => array(),
	'title'      => array(),
);
$allowedposttags['form']     = $allowed_atts;
$allowedposttags['label']    = $allowed_atts;
$allowedposttags['input']    = $allowed_atts;
$allowedposttags['textarea'] = $allowed_atts;
$allowedposttags['iframe']   = $allowed_atts;
$allowedposttags['script']   = $allowed_atts;
$allowedposttags['style']    = $allowed_atts;
$allowedposttags['strong']   = $allowed_atts;
$allowedposttags['small']    = $allowed_atts;
$allowedposttags['table']    = $allowed_atts;
$allowedposttags['span']     = $allowed_atts;
$allowedposttags['abbr']     = $allowed_atts;
$allowedposttags['code']     = $allowed_atts;
$allowedposttags['pre']      = $allowed_atts;
$allowedposttags['div']      = $allowed_atts;
$allowedposttags['img']      = $allowed_atts;
$allowedposttags['h1']       = $allowed_atts;
$allowedposttags['h2']       = $allowed_atts;
$allowedposttags['h3']       = $allowed_atts;
$allowedposttags['h4']       = $allowed_atts;
$allowedposttags['h5']       = $allowed_atts;
$allowedposttags['h6']       = $allowed_atts;
$allowedposttags['ol']       = $allowed_atts;
$allowedposttags['ul']       = $allowed_atts;
$allowedposttags['li']       = $allowed_atts;
$allowedposttags['em']       = $allowed_atts;
$allowedposttags['hr']       = $allowed_atts;
$allowedposttags['br']       = $allowed_atts;
$allowedposttags['tr']       = $allowed_atts;
$allowedposttags['td']       = $allowed_atts;
$allowedposttags['p']        = $allowed_atts;
$allowedposttags['a']        = $allowed_atts;
$allowedposttags['b']        = $allowed_atts;
$allowedposttags['i']        = $allowed_atts;


		$order_id = $the_order->get_id();
		
		switch ( $column )
		{
			case 'pataacode' :
				// Get custom post meta data
				// Loop through order items
				$display = array();
				foreach ( $the_order->get_items() as $item_id => $item ) {
					// $item_id is the current Item ID
		
					// Get the WC_Product Object
					$product = $item->get_product();
					
					// Get custom order item meta data 
					$meta_value = $item->get_meta('pataacode');
					
					$display[$item_id] = $meta_value;
				}
				// Testing output
				echo wp_kses(implode(' | ', $meta_value),$allowedposttags);

				break;
	
			case 'dlink' :
				// Get custom post meta data
				$my_var_two = wc_get_order_item_meta( $post_id, 'dlink', true );
				if(!empty($my_var_two))
				echo wp_kses($my_var_two,$allowedposttags);
				break;
		}
	}

	 /**
	 * Add Pataa Code and Dlink to order.
	 *
	 * @param WC_Order_Item_Product $item
	 * @param string                $cart_item_key
	 * @param array                 $values
	 * @param WC_Order              $order
	 */
	

	public function addMetatoOrders( $order_id, $posted ) {
		$order = wc_get_order( $order_id );
		$order->update_meta_data( 'Pataa Plugin Version', $this->version);
		$order->save();
	} 

	function prefix_footer_code() {
		$user_id = (int) get_current_user_id();
		//$api_key = get_option("settings_page_example_setting");
		$type="services";
		if(get_option("demo-radio")==1) { $type="services";} else { $type="delivery";}
		 $dir=plugin_dir_url(__FILE__);
		$markup = '<div class="create-pataa-popup-box" style="pointer-events:all;">
<div class="overlayBox"></div>
  <!-- What’s Pataa Popup -->
  <div class="what-pataa" id="whats-pataa" style="display:none;">
    <div class="pataa-modal">
      <div class="pataa-modal-content border-0">

        <div class="pataa-modal-header border-0 pb-0">
          <button type="button" id="close-btn" class="closeBtn">
            <svg xmlns="http://www.w3.org/2000/svg" width="12" height="11" viewBox="0 0 12 11" fill="none">
              <path d="M0.26238 1.30204C-0.500046 0.555501 0.567345 -0.489821 1.32975 0.256914L5.59946 4.43767L9.94541 0.256914C10.6316 -0.489628 11.6992 0.555525 11.0128 1.30204L6.66682 5.4828L11.0128 9.73822C11.699 10.4101 10.6316 11.4554 9.94541 10.7833L5.59946 6.52793L1.32975 10.7833C0.56732 11.4552 -0.500243 10.4101 0.26238 9.73822L4.53209 5.4828L0.26238 1.30204Z" fill="black" /> </svg>
          </button>
        </div>
        <div class="pataa-modal-body py-0">
          <div class="pataa-logo text-center">
            <svg xmlns="http://www.w3.org/2000/svg" width="68" height="60" viewBox="0 0 68 60" fill="none">
              <path d="M6.89164 43.2876C7.99799 43.2876 9.00446 43.5627 9.91106 44.1129C10.8176 44.6555 11.5283 45.4082 12.0431 46.3711C12.5578 47.3263 12.8152 48.3886 12.8152 49.5578C12.8152 50.727 12.5578 51.793 12.0431 52.7559C11.5283 53.7111 10.8176 54.4638 9.91106 55.0141C9.00446 55.5566 7.99799 55.8279 6.89164 55.8279C6.01578 55.8279 5.21675 55.6522 4.49455 55.3006C3.77235 54.9491 3.15771 54.4486 2.65063 53.799V60.0004H0V43.5742H2.65063V45.3051C3.15003 44.6632 3.76082 44.1664 4.48302 43.8149C5.21291 43.4634 6.01578 43.2876 6.89164 43.2876ZM3.71088 52.2171C4.4254 52.9278 5.31279 53.2832 6.37304 53.2832C7.43329 53.2832 8.31684 52.9278 9.02367 52.2171C9.7305 51.4988 10.0839 50.6123 10.0839 49.5578C10.0839 48.5032 9.7305 47.6167 9.02367 46.8984C8.31684 46.1801 7.43329 45.8209 6.37304 45.8209C5.31279 45.8209 4.4254 46.1801 3.71088 46.8984C3.00405 47.6167 2.65063 48.5032 2.65063 49.5578C2.65063 50.6123 3.00405 51.4988 3.71088 52.2171Z" fill="#1C1C1C" />
              <path d="M24.72 43.5742H27.3706V55.5414H24.72V53.8219C23.6598 55.1593 22.2538 55.8279 20.5021 55.8279C19.388 55.8279 18.3777 55.5566 17.4711 55.0141C16.5645 54.4638 15.8538 53.7111 15.3391 52.7559C14.832 51.8007 14.5785 50.7346 14.5785 49.5578C14.5785 48.3809 14.832 47.3149 15.3391 46.3597C15.8538 45.4044 16.5645 44.6555 17.4711 44.1129C18.3777 43.5627 19.388 43.2876 20.5021 43.2876C22.2615 43.2876 23.6674 43.9525 24.72 45.2821V43.5742ZM21.0207 53.2832C22.0809 53.2832 22.9606 52.9278 23.6598 52.2171C24.3666 51.4988 24.72 50.6123 24.72 49.5578C24.72 48.4956 24.3666 47.6091 23.6598 46.8984C22.9606 46.1801 22.0809 45.8209 21.0207 45.8209C19.9527 45.8209 19.0615 46.1801 18.347 46.8984C17.6401 47.6091 17.2867 48.4956 17.2867 49.5578C17.2867 50.6123 17.6401 51.4988 18.347 52.2171C19.0615 52.9278 19.9527 53.2832 21.0207 53.2832Z" fill="#1C1C1C" />
              <path d="M37.7657 45.9585H34.366V51.6211C34.366 52.1713 34.5158 52.5878 34.8155 52.8705C35.1228 53.1456 35.5569 53.2832 36.1177 53.2832C36.6479 53.2832 37.1972 53.1456 37.7657 52.8705V55.335C37.1127 55.6636 36.3789 55.8279 35.5646 55.8279C34.2969 55.8279 33.3403 55.4955 32.695 54.8307C32.0496 54.1658 31.7269 53.2373 31.7269 52.0452V45.9585H29.6871V43.5742H31.7269V40.4678H34.366V43.5742H37.7657V45.9585Z" fill="#1C1C1C" />
              <path d="M49.198 43.5742H51.8486V55.5414H49.198V53.8219C48.1378 55.1593 46.7318 55.8279 44.9801 55.8279C43.866 55.8279 42.8557 55.5566 41.9491 55.0141C41.0425 54.4638 40.3318 53.7111 39.8171 52.7559C39.31 51.8007 39.0565 50.7346 39.0565 49.5578C39.0565 48.3809 39.31 47.3149 39.8171 46.3597C40.3318 45.4044 41.0425 44.6555 41.9491 44.1129C42.8557 43.5627 43.866 43.2876 44.9801 43.2876C46.7395 43.2876 48.1454 43.9525 49.198 45.2821V43.5742ZM45.4987 53.2832C46.5589 53.2832 47.4386 52.9278 48.1378 52.2171C48.8446 51.4988 49.198 50.6123 49.198 49.5578C49.198 48.4956 48.8446 47.6091 48.1378 46.8984C47.4386 46.1801 46.5589 45.8209 45.4987 45.8209C44.4307 45.8209 43.5395 46.1801 42.825 46.8984C42.1181 47.6091 41.7647 48.4956 41.7647 49.5578C41.7647 50.6123 42.1181 51.4988 42.825 52.2171C43.5395 52.9278 44.4307 53.2832 45.4987 53.2832Z" fill="#1C1C1C" />
              <path d="M64.4564 43.5742H67.1071V55.5414H64.4564V53.8219C63.3962 55.1593 61.9902 55.8279 60.2385 55.8279C59.1244 55.8279 58.1141 55.5566 57.2075 55.0141C56.3009 54.4638 55.5903 53.7111 55.0755 52.7559C54.5684 51.8007 54.3149 50.7346 54.3149 49.5578C54.3149 48.3809 54.5684 47.3149 55.0755 46.3597C55.5903 45.4044 56.3009 44.6555 57.2075 44.1129C58.1141 43.5627 59.1244 43.2876 60.2385 43.2876C61.9979 43.2876 63.4039 43.9525 64.4564 45.2821V43.5742ZM60.7571 53.2832C61.8173 53.2832 62.697 52.9278 63.3962 52.2171C64.103 51.4988 64.4564 50.6123 64.4564 49.5578C64.4564 48.4956 64.103 47.6091 63.3962 46.8984C62.697 46.1801 61.8173 45.8209 60.7571 45.8209C59.6891 45.8209 58.7979 46.1801 58.0834 46.8984C57.3766 47.6091 57.0231 48.4956 57.0231 49.5578C57.0231 50.6123 57.3766 51.4988 58.0834 52.2171C58.7979 52.9278 59.6891 53.2832 60.7571 53.2832Z" fill="#1C1C1C" />
              <path d="M58.9336 32.925L33.6476 0L27.2656 8.26752L46.1697 32.925H58.9336Z" fill="#E39D02" />
              <path d="M8.3125 32.925L33.5985 0L39.9805 8.26752L21.0764 32.925H8.3125Z" fill="#FFC543" /> 
			</svg>
          </div>
          <p class="pataa-top-title mb-1 text-center"><span>Pataa</span> is your unique & personalized</p>

			<div class="pataa-plate-box  text-center">
			<svg xmlns="http://www.w3.org/2000/svg" width="237" height="94" viewBox="0 0 237 94" fill="none">
<rect x="0.5" y="11.5" width="236" height="56" stroke="#C0C8D9" stroke-dasharray="5 5"/>
<rect x="26" y="8" width="177" height="8" fill="white"/>
<rect x="15" y="63" width="206" height="8" fill="white"/>
<path d="M47.744 11.1473C47.744 12.1393 47.5573 12.9979 47.184 13.7233C46.8213 14.4379 46.336 15.0299 45.728 15.4993C45.1307 15.9579 44.4533 16.2993 43.696 16.5233C42.9387 16.7366 42.1707 16.8433 41.392 16.8433H37.168V5.51526H41.264C42.064 5.51526 42.8533 5.61126 43.632 5.80326C44.4107 5.98459 45.104 6.29393 45.712 6.73126C46.32 7.15793 46.8107 7.73393 47.184 8.45926C47.5573 9.18459 47.744 10.0806 47.744 11.1473ZM44.896 11.1473C44.896 10.5073 44.7893 9.97926 44.576 9.56326C44.3733 9.13659 44.096 8.80059 43.744 8.55526C43.4027 8.29926 43.008 8.11793 42.56 8.01126C42.1227 7.90459 41.6693 7.85126 41.2 7.85126H39.84V14.4753H41.136C41.6267 14.4753 42.096 14.4219 42.544 14.3153C43.0027 14.1979 43.4027 14.0113 43.744 13.7553C44.096 13.4993 44.3733 13.1579 44.576 12.7313C44.7893 12.3046 44.896 11.7766 44.896 11.1473ZM52.2626 6.33126C52.2626 6.53393 52.22 6.72593 52.1346 6.90726C52.06 7.07793 51.9533 7.22726 51.8146 7.35526C51.6866 7.48326 51.5266 7.58459 51.3346 7.65926C51.1533 7.73393 50.9613 7.77126 50.7586 7.77126C50.332 7.77126 49.9746 7.63259 49.6866 7.35526C49.3986 7.06726 49.2546 6.72593 49.2546 6.33126C49.2546 6.13926 49.292 5.95793 49.3666 5.78726C49.4413 5.60593 49.548 5.45126 49.6866 5.32326C49.8253 5.19526 49.9853 5.09393 50.1666 5.01926C50.348 4.93393 50.5453 4.89126 50.7586 4.89126C50.9613 4.89126 51.1533 4.92859 51.3346 5.00326C51.5266 5.07793 51.6866 5.17926 51.8146 5.30726C51.9533 5.43526 52.06 5.58993 52.1346 5.77126C52.22 5.94193 52.2626 6.12859 52.2626 6.33126ZM49.4466 16.8433V8.87526H52.0706V16.8433H49.4466ZM62.597 16.0913C62.597 16.8699 62.485 17.5473 62.261 18.1233C62.037 18.6993 61.7223 19.1739 61.317 19.5473C60.9117 19.9313 60.4157 20.2139 59.829 20.3953C59.253 20.5873 58.613 20.6833 57.909 20.6833C57.205 20.6833 56.4797 20.5766 55.733 20.3633C54.997 20.1499 54.357 19.8406 53.813 19.4353L55.125 17.5633C55.509 17.9046 55.9303 18.1553 56.389 18.3153C56.8583 18.4859 57.317 18.5713 57.765 18.5713C58.533 18.5713 59.0983 18.3686 59.461 17.9633C59.8343 17.5579 60.021 17.0193 60.021 16.3473V15.8673H59.973C59.7277 16.1873 59.397 16.4433 58.981 16.6353C58.565 16.8273 58.0903 16.9233 57.557 16.9233C56.949 16.9233 56.4103 16.8166 55.941 16.6033C55.4717 16.3793 55.0717 16.0806 54.741 15.7073C54.421 15.3339 54.1757 14.9019 54.005 14.4113C53.8343 13.9099 53.749 13.3819 53.749 12.8273C53.749 12.2726 53.8343 11.7446 54.005 11.2433C54.1757 10.7419 54.421 10.2993 54.741 9.91526C55.0717 9.53126 55.4717 9.22726 55.941 9.00326C56.4103 8.76859 56.9437 8.65126 57.541 8.65126C58.0423 8.65126 58.5223 8.75259 58.981 8.95526C59.4397 9.15793 59.8077 9.47259 60.085 9.89926H60.117V8.87526H62.597V16.0913ZM60.101 12.8113C60.101 12.5446 60.053 12.2886 59.957 12.0433C59.8717 11.7979 59.7437 11.5846 59.573 11.4033C59.4023 11.2113 59.1997 11.0619 58.965 10.9553C58.7303 10.8486 58.4637 10.7953 58.165 10.7953C57.8663 10.7953 57.5997 10.8486 57.365 10.9553C57.141 11.0619 56.949 11.2059 56.789 11.3873C56.629 11.5686 56.5063 11.7819 56.421 12.0273C56.3357 12.2726 56.293 12.5339 56.293 12.8113C56.293 13.0779 56.3357 13.3339 56.421 13.5793C56.5063 13.8246 56.629 14.0433 56.789 14.2353C56.949 14.4166 57.141 14.5659 57.365 14.6833C57.5997 14.7899 57.8663 14.8433 58.165 14.8433C58.4637 14.8433 58.7303 14.7899 58.965 14.6833C59.2103 14.5659 59.413 14.4166 59.573 14.2353C59.7437 14.0539 59.8717 13.8406 59.957 13.5953C60.053 13.3499 60.101 13.0886 60.101 12.8113ZM67.5283 6.33126C67.5283 6.53393 67.4856 6.72593 67.4003 6.90726C67.3256 7.07793 67.2189 7.22726 67.0803 7.35526C66.9523 7.48326 66.7923 7.58459 66.6003 7.65926C66.4189 7.73393 66.2269 7.77126 66.0243 7.77126C65.5976 7.77126 65.2403 7.63259 64.9523 7.35526C64.6643 7.06726 64.5203 6.72593 64.5203 6.33126C64.5203 6.13926 64.5576 5.95793 64.6323 5.78726C64.7069 5.60593 64.8136 5.45126 64.9523 5.32326C65.0909 5.19526 65.2509 5.09393 65.4323 5.01926C65.6136 4.93393 65.8109 4.89126 66.0243 4.89126C66.2269 4.89126 66.4189 4.92859 66.6003 5.00326C66.7923 5.07793 66.9523 5.17926 67.0803 5.30726C67.2189 5.43526 67.3256 5.58993 67.4003 5.77126C67.4856 5.94193 67.5283 6.12859 67.5283 6.33126ZM64.7122 16.8433V8.87526H67.3363V16.8433H64.7122ZM72.2626 10.8433V13.8833C72.2626 14.2566 72.332 14.5393 72.4706 14.7313C72.62 14.9126 72.8813 15.0033 73.2546 15.0033C73.3826 15.0033 73.516 14.9926 73.6546 14.9713C73.804 14.9499 73.9266 14.9179 74.0226 14.8753L74.0546 16.7953C73.8733 16.8593 73.644 16.9126 73.3666 16.9553C73.0893 17.0086 72.812 17.0353 72.5346 17.0353C72.0013 17.0353 71.5533 16.9713 71.1906 16.8433C70.828 16.7046 70.5346 16.5126 70.3106 16.2673C70.0973 16.0113 69.9426 15.7126 69.8466 15.3713C69.7506 15.0193 69.7026 14.6299 69.7026 14.2033V10.8433H68.4226V8.87526H69.6866V6.77926H72.2626V8.87526H74.1346V10.8433H72.2626ZM80.0718 13.3713H79.7358C79.4478 13.3713 79.1544 13.3873 78.8558 13.4193C78.5678 13.4406 78.3064 13.4886 78.0718 13.5633C77.8478 13.6379 77.6611 13.7499 77.5118 13.8993C77.3624 14.0379 77.2878 14.2246 77.2878 14.4593C77.2878 14.6086 77.3198 14.7366 77.3838 14.8433C77.4584 14.9499 77.5491 15.0353 77.6558 15.0993C77.7624 15.1633 77.8851 15.2113 78.0238 15.2433C78.1624 15.2646 78.2958 15.2753 78.4238 15.2753C78.9571 15.2753 79.3624 15.1313 79.6398 14.8433C79.9278 14.5446 80.0718 14.1446 80.0718 13.6433V13.3713ZM75.2558 9.96326C75.7251 9.51526 76.2691 9.17926 76.8878 8.95526C77.5171 8.73126 78.1571 8.61926 78.8078 8.61926C79.4798 8.61926 80.0451 8.70459 80.5038 8.87526C80.9731 9.03526 81.3518 9.29126 81.6398 9.64326C81.9278 9.98459 82.1358 10.4219 82.2638 10.9553C82.4024 11.4779 82.4718 12.1019 82.4718 12.8273V16.8433H80.0718V15.9953H80.0238C79.8211 16.3259 79.5118 16.5819 79.0958 16.7633C78.6904 16.9446 78.2478 17.0353 77.7678 17.0353C77.4478 17.0353 77.1171 16.9926 76.7758 16.9073C76.4344 16.8219 76.1198 16.6833 75.8318 16.4913C75.5544 16.2993 75.3251 16.0433 75.1438 15.7233C74.9624 15.4033 74.8717 15.0086 74.8717 14.5393C74.8717 13.9633 75.0264 13.4993 75.3358 13.1473C75.6558 12.7953 76.0611 12.5233 76.5518 12.3313C77.0531 12.1393 77.6078 12.0113 78.2158 11.9473C78.8238 11.8833 79.4158 11.8513 79.9918 11.8513V11.7233C79.9918 11.3286 79.8531 11.0406 79.5758 10.8593C79.2984 10.6673 78.9571 10.5713 78.5518 10.5713C78.1784 10.5713 77.8158 10.6513 77.4638 10.8113C77.1224 10.9713 76.8291 11.1633 76.5838 11.3873L75.2558 9.96326ZM84.4622 16.8433V4.74726H87.1183V16.8433H84.4622ZM100.739 16.8433L99.8586 14.6193H95.4746L94.6426 16.8433H91.6666L96.4186 5.51526H99.0746L103.779 16.8433H100.739ZM97.6986 8.53926L96.2586 12.4273H99.1066L97.6986 8.53926ZM110.603 16.8433V15.8033H110.571C110.315 16.2086 109.947 16.5233 109.467 16.7473C108.998 16.9606 108.496 17.0673 107.963 17.0673C107.366 17.0673 106.832 16.9499 106.363 16.7153C105.894 16.4806 105.494 16.1713 105.163 15.7873C104.843 15.3926 104.598 14.9393 104.427 14.4273C104.256 13.9153 104.171 13.3819 104.171 12.8273C104.171 12.2726 104.256 11.7446 104.427 11.2433C104.608 10.7313 104.859 10.2833 105.179 9.89926C105.51 9.51526 105.904 9.21126 106.363 8.98726C106.832 8.76326 107.355 8.65126 107.931 8.65126C108.518 8.65126 109.014 8.76326 109.419 8.98726C109.824 9.21126 110.139 9.45659 110.363 9.72326H110.395V4.74726H113.019V16.8433H110.603ZM110.507 12.8433C110.507 12.5873 110.459 12.3366 110.363 12.0913C110.278 11.8459 110.15 11.6273 109.979 11.4353C109.819 11.2433 109.622 11.0886 109.387 10.9713C109.152 10.8539 108.886 10.7953 108.587 10.7953C108.278 10.7953 108.006 10.8539 107.771 10.9713C107.536 11.0886 107.339 11.2433 107.179 11.4353C107.019 11.6166 106.896 11.8299 106.811 12.0753C106.736 12.3206 106.699 12.5713 106.699 12.8273C106.699 13.0833 106.736 13.3393 106.811 13.5953C106.896 13.8406 107.019 14.0593 107.179 14.2513C107.339 14.4433 107.536 14.5979 107.771 14.7153C108.006 14.8326 108.278 14.8913 108.587 14.8913C108.886 14.8913 109.152 14.8326 109.387 14.7153C109.622 14.5979 109.819 14.4433 109.979 14.2513C110.15 14.0593 110.278 13.8406 110.363 13.5953C110.459 13.3499 110.507 13.0993 110.507 12.8433ZM121.134 16.8433V15.8033H121.102C120.846 16.2086 120.478 16.5233 119.998 16.7473C119.529 16.9606 119.027 17.0673 118.494 17.0673C117.897 17.0673 117.363 16.9499 116.894 16.7153C116.425 16.4806 116.025 16.1713 115.694 15.7873C115.374 15.3926 115.129 14.9393 114.958 14.4273C114.787 13.9153 114.702 13.3819 114.702 12.8273C114.702 12.2726 114.787 11.7446 114.958 11.2433C115.139 10.7313 115.39 10.2833 115.71 9.89926C116.041 9.51526 116.435 9.21126 116.894 8.98726C117.363 8.76326 117.886 8.65126 118.462 8.65126C119.049 8.65126 119.545 8.76326 119.95 8.98726C120.355 9.21126 120.67 9.45659 120.894 9.72326H120.926V4.74726H123.55V16.8433H121.134ZM121.038 12.8433C121.038 12.5873 120.99 12.3366 120.894 12.0913C120.809 11.8459 120.681 11.6273 120.51 11.4353C120.35 11.2433 120.153 11.0886 119.918 10.9713C119.683 10.8539 119.417 10.7953 119.118 10.7953C118.809 10.7953 118.537 10.8539 118.302 10.9713C118.067 11.0886 117.87 11.2433 117.71 11.4353C117.55 11.6166 117.427 11.8299 117.342 12.0753C117.267 12.3206 117.23 12.5713 117.23 12.8273C117.23 13.0833 117.267 13.3393 117.342 13.5953C117.427 13.8406 117.55 14.0593 117.71 14.2513C117.87 14.4433 118.067 14.5979 118.302 14.7153C118.537 14.8326 118.809 14.8913 119.118 14.8913C119.417 14.8913 119.683 14.8326 119.918 14.7153C120.153 14.5979 120.35 14.4433 120.51 14.2513C120.681 14.0593 120.809 13.8406 120.894 13.5953C120.99 13.3499 121.038 13.0993 121.038 12.8433ZM130.801 11.0193C130.684 10.9873 130.567 10.9659 130.449 10.9553C130.343 10.9446 130.236 10.9393 130.129 10.9393C129.777 10.9393 129.479 11.0033 129.233 11.1313C128.999 11.2593 128.807 11.4139 128.657 11.5953C128.519 11.7766 128.417 11.9739 128.353 12.1873C128.289 12.4006 128.257 12.5873 128.257 12.7473V16.8433H125.633V8.87526H128.161V10.0273H128.193C128.396 9.62193 128.684 9.29126 129.057 9.03526C129.431 8.77926 129.863 8.65126 130.353 8.65126C130.46 8.65126 130.561 8.65659 130.657 8.66726C130.764 8.67793 130.849 8.69393 130.913 8.71526L130.801 11.0193ZM137.184 11.9473C137.184 11.5313 137.051 11.1739 136.784 10.8753C136.528 10.5766 136.139 10.4273 135.616 10.4273C135.36 10.4273 135.125 10.4699 134.912 10.5553C134.699 10.6299 134.512 10.7366 134.352 10.8753C134.192 11.0139 134.064 11.1793 133.968 11.3713C133.872 11.5526 133.819 11.7446 133.808 11.9473H137.184ZM139.6 12.9553C139.6 13.0619 139.6 13.1686 139.6 13.2753C139.6 13.3819 139.595 13.4833 139.584 13.5793H133.808C133.829 13.8033 133.893 14.0059 134 14.1873C134.117 14.3686 134.261 14.5286 134.432 14.6673C134.613 14.7953 134.811 14.8966 135.024 14.9713C135.248 15.0459 135.477 15.0833 135.712 15.0833C136.128 15.0833 136.48 15.0086 136.768 14.8593C137.056 14.6993 137.291 14.4966 137.472 14.2513L139.296 15.4033C138.923 15.9473 138.427 16.3686 137.808 16.6673C137.2 16.9553 136.491 17.0993 135.68 17.0993C135.083 17.0993 134.517 17.0086 133.984 16.8273C133.451 16.6353 132.981 16.3633 132.576 16.0113C132.181 15.6486 131.867 15.2059 131.632 14.6833C131.408 14.1606 131.296 13.5633 131.296 12.8913C131.296 12.2406 131.408 11.6539 131.632 11.1313C131.856 10.5979 132.16 10.1499 132.544 9.78726C132.928 9.41393 133.381 9.12593 133.904 8.92326C134.427 8.72059 134.992 8.61926 135.6 8.61926C136.187 8.61926 136.725 8.72059 137.216 8.92326C137.707 9.11526 138.128 9.39793 138.48 9.77126C138.832 10.1446 139.104 10.5979 139.296 11.1313C139.499 11.6646 139.6 12.2726 139.6 12.9553ZM145.915 11.2273C145.702 11.0246 145.451 10.8539 145.163 10.7153C144.875 10.5766 144.571 10.5073 144.251 10.5073C144.006 10.5073 143.776 10.5553 143.563 10.6513C143.36 10.7473 143.259 10.9126 143.259 11.1473C143.259 11.3713 143.371 11.5313 143.595 11.6273C143.83 11.7233 144.203 11.8299 144.715 11.9473C145.014 12.0113 145.312 12.1019 145.611 12.2193C145.92 12.3366 146.198 12.4913 146.443 12.6833C146.688 12.8753 146.886 13.1099 147.035 13.3873C147.184 13.6646 147.259 13.9953 147.259 14.3793C147.259 14.8806 147.158 15.3073 146.955 15.6593C146.752 16.0006 146.486 16.2779 146.155 16.4913C145.835 16.7046 145.472 16.8593 145.067 16.9553C144.662 17.0513 144.256 17.0993 143.851 17.0993C143.2 17.0993 142.56 16.9979 141.931 16.7953C141.312 16.5819 140.795 16.2726 140.379 15.8673L141.851 14.3153C142.086 14.5713 142.374 14.7846 142.715 14.9553C143.056 15.1259 143.419 15.2113 143.803 15.2113C144.016 15.2113 144.224 15.1633 144.427 15.0673C144.64 14.9606 144.747 14.7793 144.747 14.5233C144.747 14.2779 144.619 14.0966 144.363 13.9793C144.107 13.8619 143.707 13.7393 143.163 13.6113C142.886 13.5473 142.608 13.4619 142.331 13.3553C142.054 13.2486 141.803 13.1046 141.579 12.9233C141.366 12.7419 141.19 12.5179 141.051 12.2513C140.912 11.9846 140.843 11.6646 140.843 11.2913C140.843 10.8113 140.944 10.4059 141.147 10.0753C141.35 9.73393 141.611 9.45659 141.931 9.24326C142.251 9.02993 142.603 8.87526 142.987 8.77926C143.382 8.6726 143.771 8.61926 144.155 8.61926C144.752 8.61926 145.334 8.71526 145.899 8.90726C146.475 9.08859 146.96 9.36593 147.355 9.73926L145.915 11.2273ZM153.462 11.2273C153.249 11.0246 152.998 10.8539 152.71 10.7153C152.422 10.5766 152.118 10.5073 151.798 10.5073C151.553 10.5073 151.323 10.5553 151.11 10.6513C150.907 10.7473 150.806 10.9126 150.806 11.1473C150.806 11.3713 150.918 11.5313 151.142 11.6273C151.377 11.7233 151.75 11.8299 152.262 11.9473C152.561 12.0113 152.859 12.1019 153.158 12.2193C153.467 12.3366 153.745 12.4913 153.99 12.6833C154.235 12.8753 154.433 13.1099 154.582 13.3873C154.731 13.6646 154.806 13.9953 154.806 14.3793C154.806 14.8806 154.705 15.3073 154.502 15.6593C154.299 16.0006 154.033 16.2779 153.702 16.4913C153.382 16.7046 153.019 16.8593 152.614 16.9553C152.209 17.0513 151.803 17.0993 151.398 17.0993C150.747 17.0993 150.107 16.9979 149.478 16.7953C148.859 16.5819 148.342 16.2726 147.926 15.8673L149.398 14.3153C149.633 14.5713 149.921 14.7846 150.262 14.9553C150.603 15.1259 150.966 15.2113 151.35 15.2113C151.563 15.2113 151.771 15.1633 151.974 15.0673C152.187 14.9606 152.294 14.7793 152.294 14.5233C152.294 14.2779 152.166 14.0966 151.91 13.9793C151.654 13.8619 151.254 13.7393 150.71 13.6113C150.433 13.5473 150.155 13.4619 149.878 13.3553C149.601 13.2486 149.35 13.1046 149.126 12.9233C148.913 12.7419 148.737 12.5179 148.598 12.2513C148.459 11.9846 148.39 11.6646 148.39 11.2913C148.39 10.8113 148.491 10.4059 148.694 10.0753C148.897 9.73393 149.158 9.45659 149.478 9.24326C149.798 9.02993 150.15 8.87526 150.534 8.77926C150.929 8.6726 151.318 8.61926 151.702 8.61926C152.299 8.61926 152.881 8.71526 153.446 8.90726C154.022 9.08859 154.507 9.36593 154.902 9.73926L153.462 11.2273ZM170.433 15.2753C169.932 15.8513 169.313 16.3099 168.577 16.6513C167.841 16.9819 166.993 17.1473 166.033 17.1473C165.158 17.1473 164.348 17.0033 163.601 16.7153C162.865 16.4273 162.225 16.0219 161.681 15.4993C161.137 14.9659 160.71 14.3313 160.401 13.5953C160.092 12.8593 159.937 12.0486 159.937 11.1633C159.937 10.2566 160.092 9.43526 160.401 8.69926C160.721 7.96326 161.158 7.33926 161.713 6.82726C162.268 6.30459 162.918 5.90459 163.665 5.62726C164.412 5.34993 165.217 5.21126 166.081 5.21126C166.881 5.21126 167.665 5.35526 168.433 5.64326C169.212 5.92059 169.841 6.33126 170.321 6.87526L168.465 8.73126C168.209 8.37926 167.873 8.11793 167.457 7.94726C167.041 7.77659 166.614 7.69126 166.177 7.69126C165.697 7.69126 165.254 7.78193 164.849 7.96326C164.454 8.13393 164.113 8.37393 163.825 8.68326C163.537 8.99259 163.313 9.36059 163.153 9.78726C162.993 10.2033 162.913 10.6619 162.913 11.1633C162.913 11.6753 162.993 12.1446 163.153 12.5713C163.313 12.9979 163.532 13.3659 163.809 13.6753C164.097 13.9739 164.438 14.2086 164.833 14.3793C165.228 14.5499 165.66 14.6353 166.129 14.6353C166.673 14.6353 167.148 14.5286 167.553 14.3153C167.958 14.1019 168.284 13.8246 168.529 13.4833L170.433 15.2753ZM179.722 12.8273C179.722 13.4779 179.605 14.0699 179.37 14.6033C179.135 15.1259 178.815 15.5739 178.41 15.9473C178.005 16.3099 177.535 16.5926 177.002 16.7953C176.469 16.9979 175.898 17.0993 175.29 17.0993C174.693 17.0993 174.122 16.9979 173.578 16.7953C173.045 16.5926 172.575 16.3099 172.17 15.9473C171.775 15.5739 171.461 15.1259 171.226 14.6033C170.991 14.0699 170.874 13.4779 170.874 12.8273C170.874 12.1766 170.991 11.5899 171.226 11.0673C171.461 10.5446 171.775 10.1019 172.17 9.73926C172.575 9.37659 173.045 9.09926 173.578 8.90726C174.122 8.71526 174.693 8.61926 175.29 8.61926C175.898 8.61926 176.469 8.71526 177.002 8.90726C177.535 9.09926 178.005 9.37659 178.41 9.73926C178.815 10.1019 179.135 10.5446 179.37 11.0673C179.605 11.5899 179.722 12.1766 179.722 12.8273ZM177.194 12.8273C177.194 12.5713 177.151 12.3206 177.066 12.0753C176.981 11.8299 176.858 11.6166 176.698 11.4353C176.538 11.2433 176.341 11.0886 176.106 10.9713C175.871 10.8539 175.599 10.7953 175.29 10.7953C174.981 10.7953 174.709 10.8539 174.474 10.9713C174.239 11.0886 174.042 11.2433 173.882 11.4353C173.733 11.6166 173.615 11.8299 173.53 12.0753C173.455 12.3206 173.418 12.5713 173.418 12.8273C173.418 13.0833 173.455 13.3339 173.53 13.5793C173.615 13.8246 173.738 14.0486 173.898 14.2513C174.058 14.4433 174.255 14.5979 174.49 14.7153C174.725 14.8326 174.997 14.8913 175.306 14.8913C175.615 14.8913 175.887 14.8326 176.122 14.7153C176.357 14.5979 176.554 14.4433 176.714 14.2513C176.874 14.0486 176.991 13.8246 177.066 13.5793C177.151 13.3339 177.194 13.0833 177.194 12.8273ZM187.415 16.8433V15.8033H187.383C187.127 16.2086 186.759 16.5233 186.279 16.7473C185.81 16.9606 185.309 17.0673 184.775 17.0673C184.178 17.0673 183.645 16.9499 183.175 16.7153C182.706 16.4806 182.306 16.1713 181.975 15.7873C181.655 15.3926 181.41 14.9393 181.239 14.4273C181.069 13.9153 180.983 13.3819 180.983 12.8273C180.983 12.2726 181.069 11.7446 181.239 11.2433C181.421 10.7313 181.671 10.2833 181.991 9.89926C182.322 9.51526 182.717 9.21126 183.175 8.98726C183.645 8.76326 184.167 8.65126 184.743 8.65126C185.33 8.65126 185.826 8.76326 186.231 8.98726C186.637 9.21126 186.951 9.45659 187.175 9.72326H187.207V4.74726H189.831V16.8433H187.415ZM187.319 12.8433C187.319 12.5873 187.271 12.3366 187.175 12.0913C187.09 11.8459 186.962 11.6273 186.791 11.4353C186.631 11.2433 186.434 11.0886 186.199 10.9713C185.965 10.8539 185.698 10.7953 185.399 10.7953C185.09 10.7953 184.818 10.8539 184.583 10.9713C184.349 11.0886 184.151 11.2433 183.991 11.4353C183.831 11.6166 183.709 11.8299 183.623 12.0753C183.549 12.3206 183.511 12.5713 183.511 12.8273C183.511 13.0833 183.549 13.3393 183.623 13.5953C183.709 13.8406 183.831 14.0593 183.991 14.2513C184.151 14.4433 184.349 14.5979 184.583 14.7153C184.818 14.8326 185.09 14.8913 185.399 14.8913C185.698 14.8913 185.965 14.8326 186.199 14.7153C186.434 14.5979 186.631 14.4433 186.791 14.2513C186.962 14.0593 187.09 13.8406 187.175 13.5953C187.271 13.3499 187.319 13.0993 187.319 12.8433ZM197.403 11.9473C197.403 11.5313 197.269 11.1739 197.003 10.8753C196.747 10.5766 196.357 10.4273 195.835 10.4273C195.579 10.4273 195.344 10.4699 195.131 10.5553C194.917 10.6299 194.731 10.7366 194.571 10.8753C194.411 11.0139 194.283 11.1793 194.187 11.3713C194.091 11.5526 194.037 11.7446 194.027 11.9473H197.403ZM199.819 12.9553C199.819 13.0619 199.819 13.1686 199.819 13.2753C199.819 13.3819 199.813 13.4833 199.803 13.5793H194.027C194.048 13.8033 194.112 14.0059 194.219 14.1873C194.336 14.3686 194.48 14.5286 194.651 14.6673C194.832 14.7953 195.029 14.8966 195.243 14.9713C195.467 15.0459 195.696 15.0833 195.931 15.0833C196.347 15.0833 196.699 15.0086 196.987 14.8593C197.275 14.6993 197.509 14.4966 197.691 14.2513L199.515 15.4033C199.141 15.9473 198.645 16.3686 198.027 16.6673C197.419 16.9553 196.709 17.0993 195.899 17.0993C195.301 17.0993 194.736 17.0086 194.203 16.8273C193.669 16.6353 193.2 16.3633 192.795 16.0113C192.4 15.6486 192.085 15.2059 191.851 14.6833C191.627 14.1606 191.515 13.5633 191.515 12.8913C191.515 12.2406 191.627 11.6539 191.851 11.1313C192.075 10.5979 192.379 10.1499 192.763 9.78726C193.147 9.41393 193.6 9.12593 194.123 8.92326C194.645 8.72059 195.211 8.61926 195.819 8.61926C196.405 8.61926 196.944 8.72059 197.435 8.92326C197.925 9.11526 198.347 9.39793 198.699 9.77126C199.051 10.1446 199.323 10.5979 199.515 11.1313C199.717 11.6646 199.819 12.2726 199.819 12.9553Z" fill="#181B21"/>
<path d="M19 47.1885C19 44.2669 21.3684 41.8984 24.29 41.8984H210.71C213.632 41.8984 216 44.2669 216 47.1885V87.8111C216 90.7327 213.632 93.1011 210.71 93.1011H24.29C21.3684 93.1011 19 90.7327 19 87.8111V47.1885Z" fill="#FFC543"/>
<path d="M19 47.1885C19 44.2669 21.3684 41.8984 24.29 41.8984H70.1369V93.0354H24.29C21.3684 93.0354 19 90.667 19 87.7454V47.1885Z" fill="#F4F4F4"/>
<path d="M30.98 74.5638C31.5444 74.5638 32.0579 74.7041 32.5204 74.9848C32.9829 75.2616 33.3455 75.6456 33.6081 76.1369C33.8707 76.6242 34.002 77.1661 34.002 77.7626C34.002 78.3591 33.8707 78.903 33.6081 79.3942C33.3455 79.8815 32.9829 80.2656 32.5204 80.5463C32.0579 80.8231 31.5444 80.9615 30.98 80.9615C30.5331 80.9615 30.1255 80.8718 29.7571 80.6925C29.3886 80.5131 29.075 80.2578 28.8163 79.9264V83.0902H27.4641V74.71H28.8163V75.593C29.0711 75.2655 29.3827 75.0121 29.7512 74.8328C30.1235 74.6534 30.5331 74.5638 30.98 74.5638ZM29.3572 79.1194C29.7218 79.4819 30.1745 79.6632 30.7154 79.6632C31.2563 79.6632 31.7071 79.4819 32.0677 79.1194C32.4283 78.7529 32.6086 78.3006 32.6086 77.7626C32.6086 77.2246 32.4283 76.7724 32.0677 76.4059C31.7071 76.0394 31.2563 75.8562 30.7154 75.8562C30.1745 75.8562 29.7218 76.0394 29.3572 76.4059C28.9966 76.7724 28.8163 77.2246 28.8163 77.7626C28.8163 78.3006 28.9966 78.7529 29.3572 79.1194Z" fill="#1C1C1C"/>
<path d="M40.0755 74.71H41.4278V80.8153H40.0755V79.9381C39.5346 80.6203 38.8173 80.9615 37.9236 80.9615C37.3553 80.9615 36.8399 80.8231 36.3773 80.5463C35.9148 80.2656 35.5523 79.8815 35.2896 79.3942C35.0309 78.9069 34.9016 78.363 34.9016 77.7626C34.9016 77.1622 35.0309 76.6184 35.2896 76.131C35.5523 75.6437 35.9148 75.2616 36.3773 74.9848C36.8399 74.7041 37.3553 74.5638 37.9236 74.5638C38.8212 74.5638 39.5385 74.9029 40.0755 75.5813V74.71ZM38.1882 79.6632C38.7291 79.6632 39.1779 79.4819 39.5346 79.1194C39.8952 78.7529 40.0755 78.3006 40.0755 77.7626C40.0755 77.2207 39.8952 76.7685 39.5346 76.4059C39.1779 76.0394 38.7291 75.8562 38.1882 75.8562C37.6434 75.8562 37.1887 76.0394 36.8242 76.4059C36.4636 76.7685 36.2833 77.2207 36.2833 77.7626C36.2833 78.3006 36.4636 78.7529 36.8242 79.1194C37.1887 79.4819 37.6434 79.6632 38.1882 79.6632Z" fill="#1C1C1C"/>
<path d="M46.7311 75.9263H44.9966V78.8153C44.9966 79.096 45.0731 79.3084 45.2259 79.4527C45.3827 79.593 45.6042 79.6632 45.8903 79.6632C46.1608 79.6632 46.441 79.593 46.7311 79.4527V80.71C46.3979 80.8777 46.0236 80.9615 45.6081 80.9615C44.9614 80.9615 44.4734 80.7919 44.1441 80.4527C43.8149 80.1135 43.6503 79.6398 43.6503 79.0316V75.9263H42.6096V74.71H43.6503V73.1252H44.9966V74.71H46.7311V75.9263Z" fill="#1C1C1C"/>
<path d="M52.5635 74.71H53.9158V80.8153H52.5635V79.9381C52.0226 80.6203 51.3053 80.9615 50.4116 80.9615C49.8433 80.9615 49.3279 80.8231 48.8653 80.5463C48.4028 80.2656 48.0403 79.8815 47.7776 79.3942C47.5189 78.9069 47.3896 78.363 47.3896 77.7626C47.3896 77.1622 47.5189 76.6184 47.7776 76.131C48.0403 75.6437 48.4028 75.2616 48.8653 74.9848C49.3279 74.7041 49.8433 74.5638 50.4116 74.5638C51.3092 74.5638 52.0265 74.9029 52.5635 75.5813V74.71ZM50.6762 79.6632C51.2171 79.6632 51.6659 79.4819 52.0226 79.1194C52.3832 78.7529 52.5635 78.3006 52.5635 77.7626C52.5635 77.2207 52.3832 76.7685 52.0226 76.4059C51.6659 76.0394 51.2171 75.8562 50.6762 75.8562C50.1314 75.8562 49.6767 76.0394 49.3122 76.4059C48.9516 76.7685 48.7713 77.2207 48.7713 77.7626C48.7713 78.3006 48.9516 78.7529 49.3122 79.1194C49.6767 79.4819 50.1314 79.6632 50.6762 79.6632Z" fill="#1C1C1C"/>
<path d="M60.348 74.71H61.7002V80.8153H60.348V79.9381C59.807 80.6203 59.0897 80.9615 58.1961 80.9615C57.6277 80.9615 57.1123 80.8231 56.6498 80.5463C56.1872 80.2656 55.8247 79.8815 55.5621 79.3942C55.3034 78.9069 55.174 78.363 55.174 77.7626C55.174 77.1622 55.3034 76.6184 55.5621 76.131C55.8247 75.6437 56.1872 75.2616 56.6498 74.9848C57.1123 74.7041 57.6277 74.5638 58.1961 74.5638C59.0937 74.5638 59.811 74.9029 60.348 75.5813V74.71ZM58.4606 79.6632C59.0016 79.6632 59.4504 79.4819 59.807 79.1194C60.1677 78.7529 60.348 78.3006 60.348 77.7626C60.348 77.2207 60.1677 76.7685 59.807 76.4059C59.4504 76.0394 59.0016 75.8562 58.4606 75.8562C57.9158 75.8562 57.4611 76.0394 57.0966 76.4059C56.736 76.7685 56.5557 77.2207 56.5557 77.7626C56.5557 78.3006 56.736 78.7529 57.0966 79.1194C57.4611 79.4819 57.9158 79.6632 58.4606 79.6632Z" fill="#1C1C1C"/>
<path d="M57.5294 69.2762L44.6292 52.4788L41.3733 56.6966L51.0176 69.2762H57.5294Z" fill="#E39D02"/>
<path d="M31.7043 69.2761L44.6045 52.4787L47.8604 56.6966L38.2161 69.2761H31.7043Z" fill="#FFC543"/>
<path d="M91.7905 68.6036L89.604 64.8477L87.4351 68.6036H84.8253L88.5812 62.1674H90.662L94.4003 68.6036H91.7905ZM104.635 74.6519L99.9977 68.9034H99.9624V74.6519H97V62.1674H99.9624V67.2458H100.015L104.477 62.1674H108.25L102.872 67.9159L108.568 74.6519H104.635ZM120.116 69.9437C120.116 70.6961 119.987 71.3838 119.728 72.0068C119.481 72.6181 119.123 73.1471 118.653 73.5938C118.183 74.0288 117.612 74.3697 116.942 74.6166C116.284 74.8635 115.549 74.9869 114.738 74.9869C113.915 74.9869 113.175 74.8635 112.516 74.6166C111.858 74.3697 111.3 74.0288 110.841 73.5938C110.383 73.1471 110.03 72.6181 109.783 72.0068C109.536 71.3838 109.413 70.6961 109.413 69.9437V62.1674H112.41V69.6969C112.41 70.0378 112.452 70.3611 112.534 70.6667C112.628 70.9723 112.763 71.2486 112.939 71.4955C113.128 71.7306 113.369 71.9187 113.662 72.0597C113.968 72.2008 114.333 72.2713 114.756 72.2713C115.179 72.2713 115.537 72.2008 115.831 72.0597C116.137 71.9187 116.384 71.7306 116.572 71.4955C116.76 71.2486 116.895 70.9723 116.978 70.6667C117.06 70.3611 117.101 70.0378 117.101 69.6969V62.1674H120.116V69.9437ZM133.875 74.6519L133.946 65.8175H133.893L130.648 74.6519H128.532L125.376 65.8175H125.323L125.394 74.6519H122.555V62.1674H126.84L129.679 70.173H129.749L132.465 62.1674H136.82V74.6519H133.875ZM147.86 74.6519L146.89 72.2008H142.059L141.142 74.6519H137.862L143.099 62.1674H146.026L151.21 74.6519H147.86ZM144.51 65.5001L142.923 69.785H146.061L144.51 65.5001ZM158.925 74.6519L156.227 69.6969H155.205V74.6519H152.242V62.1674H157.003C157.603 62.1674 158.185 62.232 158.749 62.3614C159.325 62.4789 159.836 62.6846 160.283 62.9785C160.742 63.2724 161.106 63.6603 161.376 64.1423C161.647 64.6243 161.782 65.2238 161.782 65.9409C161.782 66.7873 161.553 67.4986 161.094 68.0746C160.636 68.6506 160.001 69.0621 159.19 69.3089L162.452 74.6519H158.925ZM158.802 65.9938C158.802 65.6999 158.737 65.4648 158.608 65.2885C158.49 65.1004 158.332 64.9593 158.132 64.8653C157.944 64.7595 157.726 64.689 157.479 64.6537C157.244 64.6184 157.015 64.6008 156.792 64.6008H155.187V67.5103H156.615C156.862 67.5103 157.115 67.4927 157.374 67.4574C157.632 67.4104 157.867 67.334 158.079 67.2282C158.29 67.1224 158.461 66.9696 158.59 66.7697C158.731 66.5699 158.802 66.3112 158.802 65.9938ZM167.638 74.6519V65.4825L165.31 67.2811L163.776 65.1827L167.885 62.1674H170.6V74.6519H167.638ZM184.627 68.3744C184.627 69.256 184.539 70.0966 184.363 70.8959C184.186 71.6953 183.904 72.4007 183.516 73.0119C183.128 73.6115 182.623 74.0935 182 74.4579C181.389 74.8106 180.642 74.9869 179.76 74.9869C178.879 74.9869 178.126 74.8106 177.503 74.4579C176.88 74.0935 176.369 73.6115 175.969 73.0119C175.581 72.4007 175.299 71.6953 175.123 70.8959C174.946 70.0966 174.858 69.256 174.858 68.3744C174.858 67.4927 174.946 66.658 175.123 65.8704C175.299 65.071 175.581 64.3774 175.969 63.7897C176.369 63.1901 176.88 62.714 177.503 62.3614C178.126 62.0087 178.879 61.8323 179.76 61.8323C180.642 61.8323 181.389 62.0087 182 62.3614C182.623 62.714 183.128 63.1901 183.516 63.7897C183.904 64.3774 184.186 65.071 184.363 65.8704C184.539 66.658 184.627 67.4927 184.627 68.3744ZM181.594 68.3744C181.594 67.9864 181.571 67.5573 181.524 67.0871C181.477 66.6169 181.389 66.1819 181.259 65.7822C181.13 65.3708 180.942 65.0299 180.695 64.7595C180.46 64.4774 180.148 64.3363 179.76 64.3363C179.372 64.3363 179.055 64.4774 178.808 64.7595C178.561 65.0299 178.367 65.3708 178.226 65.7822C178.097 66.1819 178.009 66.6169 177.962 67.0871C177.915 67.5573 177.891 67.9864 177.891 68.3744C177.891 68.774 177.915 69.2149 177.962 69.6969C178.009 70.1671 178.097 70.6079 178.226 71.0194C178.367 71.4191 178.561 71.76 178.808 72.0421C179.055 72.3125 179.372 72.4477 179.76 72.4477C180.148 72.4477 180.46 72.3125 180.695 72.0421C180.942 71.76 181.13 71.4191 181.259 71.0194C181.389 70.6079 181.477 70.1671 181.524 69.6969C181.571 69.2149 181.594 68.774 181.594 68.3744ZM196.027 68.3744C196.027 69.256 195.939 70.0966 195.762 70.8959C195.586 71.6953 195.304 72.4007 194.916 73.0119C194.528 73.6115 194.023 74.0935 193.4 74.4579C192.788 74.8106 192.042 74.9869 191.16 74.9869C190.278 74.9869 189.526 74.8106 188.903 74.4579C188.28 74.0935 187.769 73.6115 187.369 73.0119C186.981 72.4007 186.699 71.6953 186.523 70.8959C186.346 70.0966 186.258 69.256 186.258 68.3744C186.258 67.4927 186.346 66.658 186.523 65.8704C186.699 65.071 186.981 64.3774 187.369 63.7897C187.769 63.1901 188.28 62.714 188.903 62.3614C189.526 62.0087 190.278 61.8323 191.16 61.8323C192.042 61.8323 192.788 62.0087 193.4 62.3614C194.023 62.714 194.528 63.1901 194.916 63.7897C195.304 64.3774 195.586 65.071 195.762 65.8704C195.939 66.658 196.027 67.4927 196.027 68.3744ZM192.994 68.3744C192.994 67.9864 192.971 67.5573 192.924 67.0871C192.876 66.6169 192.788 66.1819 192.659 65.7822C192.53 65.3708 192.342 65.0299 192.095 64.7595C191.86 64.4774 191.548 64.3363 191.16 64.3363C190.772 64.3363 190.455 64.4774 190.208 64.7595C189.961 65.0299 189.767 65.3708 189.626 65.7822C189.497 66.1819 189.409 66.6169 189.362 67.0871C189.315 67.5573 189.291 67.9864 189.291 68.3744C189.291 68.774 189.315 69.2149 189.362 69.6969C189.409 70.1671 189.497 70.6079 189.626 71.0194C189.767 71.4191 189.961 71.76 190.208 72.0421C190.455 72.3125 190.772 72.4477 191.16 72.4477C191.548 72.4477 191.86 72.3125 192.095 72.0421C192.342 71.76 192.53 71.4191 192.659 71.0194C192.788 70.6079 192.876 70.1671 192.924 69.6969C192.971 69.2149 192.994 68.774 192.994 68.3744Z" fill="black"/>
</svg>
			</div>
          <div class="pataa-features">
            <p class="text-center">Your ^pataa contains the following :</p>
            <div class="pataa-features-box  position-relative">
              <div class="triangle"></div>
              <div class="d-flex flex-wrap">
                <div class="features-pataa d-flex">
                  <svg xmlns="http://www.w3.org/2000/svg" width="24" height="30" viewBox="0 0 14 15" fill="none">
                    <path d="M0 12.4272V13.6392C0 14.1476 0.405641 14.5599 0.90639 14.5599H2.90251V12.4272H0Z" fill="#5B7ABC" />
                    <path d="M2.90251 6.80723H0V11.5887H2.90251V6.80723Z" fill="#5B7ABC" />
                    <path d="M10.2463 12.4272H3.72742V14.5599H10.2463V12.4272Z" fill="#5B7ABC" />
                    <path d="M2.90251 3.93433H0.90639C0.405641 3.93433 0 4.34666 0 4.85568V5.96806H2.90251V3.93433Z" fill="#5B7ABC" />
                    <path d="M11.0721 14.5598H12.4409C12.9411 14.5598 13.3473 14.1475 13.3473 13.6384V12.4265H11.0721V14.5598Z" fill="#5B7ABC" />
                    <path d="M8.58537 9.58002C8.51433 9.68602 8.3963 9.7495 8.26968 9.7495C8.14306 9.7495 8.02561 9.68602 7.95399 9.58002L6.3807 7.23995L6.08965 6.80723H3.72742V11.5887H10.2463V7.10949L10.1581 7.24053L8.58537 9.58002Z" fill="#5B7ABC" />
                    <path d="M12.4408 3.93433H12.3503C12.2271 4.43927 12.0157 4.90926 11.7332 5.32567C11.5762 5.55747 11.3969 5.77179 11.1987 5.96748H13.3472V4.8551C13.3466 4.34666 12.941 3.93433 12.4408 3.93433Z" fill="#5B7ABC" />
                    <path d="M13.3473 6.80723H11.0721V11.5887H13.3473V6.80723Z" fill="#5B7ABC" />
                    <path d="M4.18978 3.93433H3.72742V5.96748H5.34024C4.78678 5.42061 4.38114 4.71998 4.18978 3.93433Z" fill="#5B7ABC" />
                    <path d="M8.26987 0C6.52183 0 5.09979 1.44551 5.09979 3.22241C5.09979 3.42392 5.11813 3.62135 5.15308 3.81296C5.16453 3.87528 5.17829 3.93643 5.19318 3.99758C5.33756 4.58988 5.64351 5.11811 6.06061 5.53103C6.12306 5.59277 6.18723 5.65159 6.25484 5.70808C6.3001 5.74594 6.34651 5.78321 6.39406 5.81874L6.6261 6.16352L6.84554 6.48966L8.0321 8.25433C8.08595 8.33412 8.17476 8.38187 8.26987 8.38187C8.36498 8.38187 8.45435 8.33412 8.50764 8.25433L9.6942 6.48966L9.76066 6.39124L10.1457 5.81874C10.2631 5.7308 10.3743 5.63412 10.4786 5.53103C10.6275 5.38369 10.7627 5.22178 10.8813 5.04706C11.0945 4.73315 11.2537 4.37847 11.3466 3.99758C11.3615 3.93643 11.3752 3.87528 11.3861 3.81296C11.421 3.62135 11.4394 3.42392 11.4394 3.22241C11.4399 1.44551 10.0179 0 8.26987 0ZM10.3663 3.93235C10.3044 4.12163 10.2184 4.29926 10.1124 4.46233C9.78357 4.96669 9.25991 5.32719 8.6503 5.43494C8.644 5.4361 8.63769 5.43727 8.63139 5.43843C8.63082 5.43843 8.62967 5.43843 8.6291 5.43843C8.51222 5.45765 8.39248 5.46872 8.26987 5.46872C8.14783 5.46872 8.02809 5.45823 7.91121 5.43901C7.91006 5.43901 7.90892 5.43901 7.90777 5.43843C7.89975 5.43727 7.8923 5.43552 7.88428 5.43377C7.08159 5.28992 6.42844 4.70636 6.17463 3.93643C6.17234 3.92886 6.16947 3.92187 6.16718 3.9143C6.1603 3.89217 6.15343 3.87003 6.14713 3.84732C6.14369 3.83626 6.14082 3.82461 6.13739 3.81354C6.13739 3.81296 6.13681 3.8118 6.13681 3.81121C6.13166 3.79141 6.1265 3.77161 6.12192 3.75181C6.11848 3.73667 6.11504 3.72094 6.1116 3.7058C6.10759 3.68774 6.10416 3.66969 6.10072 3.65222C6.09728 3.63416 6.09384 3.61553 6.09098 3.59689C6.08811 3.58117 6.08582 3.56486 6.08353 3.54855C6.08067 3.527 6.0778 3.50545 6.07551 3.48332C6.07379 3.46993 6.07207 3.45653 6.07093 3.44255C6.06806 3.41576 6.06634 3.38839 6.06462 3.36102C6.06405 3.35228 6.06348 3.34355 6.0629 3.33423C6.06119 3.29696 6.06004 3.26026 6.06004 3.22241C6.06004 3.1269 6.06634 3.03313 6.0778 2.94053C6.20557 1.90502 7.02602 1.0885 8.05272 0.987165C8.12377 0.980176 8.19596 0.976099 8.2693 0.976099C8.33346 0.976099 8.39706 0.979593 8.46008 0.984835C9.59107 1.08326 10.4791 2.04713 10.4791 3.22183C10.4791 3.25852 10.478 3.29521 10.4763 3.3319C10.4757 3.34471 10.4745 3.35752 10.4734 3.37092C10.4717 3.39422 10.4705 3.41693 10.4682 3.43964C10.4665 3.45595 10.4648 3.47226 10.4625 3.48798C10.4602 3.5072 10.4579 3.52584 10.4556 3.54506C10.4533 3.56311 10.4499 3.58117 10.447 3.59922C10.4442 3.61553 10.4413 3.63183 10.4384 3.64814C10.4344 3.66794 10.4304 3.68774 10.4264 3.70696C10.4235 3.72036 10.4201 3.73434 10.4172 3.74773C10.4121 3.76928 10.4069 3.79083 10.4012 3.81179C10.3983 3.82228 10.3955 3.83276 10.3926 3.84266C10.3857 3.86654 10.3789 3.89042 10.3714 3.9143C10.3697 3.92129 10.368 3.92653 10.3663 3.93235Z" fill="#FFCC4B" />
                    <path d="M8.27019 2.05035C7.63365 2.05035 7.11743 2.57509 7.11743 3.22213C7.11743 3.43762 7.17473 3.63913 7.27499 3.81268C7.47495 4.16037 7.84564 4.39392 8.27076 4.39392C8.69531 4.39392 9.066 4.16037 9.26653 3.81268C9.36622 3.63913 9.42409 3.43762 9.42409 3.22213C9.42294 2.57509 8.90672 2.05035 8.27019 2.05035Z" fill="#FFCC4B" /> </svg>
                  <p>Accurate location
                    <br> on the map</p>
                </div>
                <div class="features-pataa d-flex mb-01">
                  <svg xmlns="http://www.w3.org/2000/svg" width="34" height="30" viewBox="0 0 17 15" fill="none">
                    <path d="M14.3802 5.46711C13.502 5.46711 12.6968 5.98947 12.355 6.77271C12.0132 7.55596 12.2083 8.48188 12.8183 9.09916C13.4529 9.71644 14.3802 9.8824 15.2099 9.54989C16.0151 9.21737 16.552 8.43413 16.552 7.57983C16.576 6.41632 15.6002 5.46711 14.3802 5.46711ZM15.5757 7.17569L14.3311 8.69501C14.282 8.76606 14.1844 8.81381 14.1114 8.81381H14.0868C14.0138 8.81381 13.9162 8.78993 13.8671 8.71889L13.2326 8.10161C13.1105 7.98281 13.1105 7.79297 13.2326 7.67417C13.3547 7.55538 13.5499 7.55538 13.672 7.67417L14.0378 8.02998L15.0626 6.77213C15.1357 6.67721 15.2332 6.65333 15.3554 6.65333C15.4775 6.67721 15.5505 6.74825 15.5996 6.84318C15.6487 6.96256 15.6487 7.08077 15.5757 7.17569Z" fill="#FFCC4B" />
                    <path d="M14.99 12.3034C14.8433 11.805 14.7457 11.3065 14.6972 10.7841C14.6727 10.6181 14.6727 10.4516 14.6727 10.2856C14.5751 10.2856 14.4775 10.3095 14.38 10.3095C13.0869 10.3095 11.9644 9.45522 11.6472 8.24454C11.3299 7.03385 11.9154 5.75213 13.0623 5.15872C14.2093 4.56532 15.6 4.80291 16.4782 5.75213C16.5512 5.49124 16.5758 5.25364 16.5758 4.99276C16.6003 4.3516 16.5267 3.71103 16.3561 3.09375C16.1609 2.38155 15.746 1.76427 15.1845 1.31354C14.013 0.340452 12.9396 -0.0631084 11.6705 0.00793689C10.9629 0.0556887 10.2553 0.173903 9.54774 0.340452C8.79106 0.459249 8.10802 0.815058 7.57104 1.33742C7.20527 1.74098 6.93648 2.21558 6.76587 2.73794C6.69284 2.99883 6.6192 3.2603 6.57071 3.52119V3.54506C6.52163 3.75878 6.44859 3.9725 6.35101 4.18622C6.30192 4.28114 6.27798 4.37606 6.22889 4.49486C6.20435 4.54261 6.20435 4.58978 6.20435 4.63753C6.20435 4.68528 6.30192 4.7802 6.37496 4.85125C6.57011 5.01721 6.71678 5.23093 6.71678 5.4924C6.71678 5.6112 6.69224 5.73 6.6192 5.82492C6.42405 6.2046 6.20435 6.56099 5.91161 6.86905C5.81403 6.98785 5.69191 7.12994 5.56979 7.27261C5.49676 7.36753 5.42312 7.46246 5.37463 7.58125C5.39918 7.629 5.44767 7.6523 5.47221 7.67617C5.5213 7.72393 5.59433 7.74722 5.64282 7.79497C5.91101 7.88989 6.10617 8.12749 6.20375 8.38837C6.22829 8.57822 6.20375 8.76806 6.13071 8.9579C6.10617 9.02895 6.05768 9.10057 6.03314 9.14774C6.20375 9.1955 6.47254 9.26654 6.98497 9.36146C7.25316 9.40921 7.42437 9.62235 7.44832 9.88382C7.47286 10.1447 7.3262 10.3823 7.08255 10.4533C6.91194 10.5244 6.74073 10.596 6.59466 10.6671C6.6192 10.7381 6.64375 10.8097 6.66769 10.9047C6.66769 10.9285 6.69224 10.9757 6.69224 11.0235C6.74133 11.1894 6.71678 11.3793 6.66769 11.5458C6.66769 11.5936 6.64315 11.6407 6.64315 11.6885C6.6186 11.8312 6.64315 11.9733 6.69224 12.092C6.74133 12.2108 6.8389 12.4246 7.05801 12.3768C7.42377 12.258 7.7656 12.1159 8.08287 11.9494C8.37561 11.8067 8.69289 11.6646 9.01016 11.5219C9.22987 11.4509 9.44957 11.356 9.59563 11.3082C9.76624 11.2372 9.88837 11.1894 9.9614 11.1655C10.8641 10.8569 11.0348 10.5244 11.0348 10.3113C11.0348 10.1453 11.1569 10.0026 11.3275 10.0026C11.4981 10.0026 11.6448 10.1453 11.6448 10.2874C11.6693 10.9047 11.1569 11.4031 10.132 11.7351C10.059 11.759 9.93686 11.8061 9.79019 11.8539L9.66807 11.9016C10.229 12.6138 10.6929 13.9427 10.8881 14.56L15.8412 14.5361C15.7921 14.4651 15.7437 14.3702 15.6946 14.2752C15.6 14.0359 15.063 12.5643 14.99 12.3034Z" fill="#5B7ABC" />
                    <path d="M4.53906 11.6139C4.48997 11.6139 4.41693 11.59 4.39239 11.5429C3.48965 10.6647 3.48965 9.26416 4.39239 8.38599C4.46542 8.31495 4.61209 8.31495 4.68512 8.38599C4.75816 8.45704 4.75816 8.59971 4.68512 8.67076C3.95299 9.38296 3.95299 10.5459 4.68512 11.2342C4.75816 11.3053 4.75816 11.4479 4.68512 11.519C4.66058 11.59 4.61209 11.6139 4.53906 11.6139Z" fill="#FFCC4B" />
                    <path d="M3.24536 12.9662C3.19628 12.9662 3.12324 12.9424 3.0987 12.8952C2.29353 12.1119 1.85413 11.0672 1.85413 9.95204C1.85413 8.86016 2.29353 7.79215 3.0987 7.0089C3.17173 6.93786 3.3184 6.93786 3.39143 7.0089C3.46447 7.07995 3.46447 7.22262 3.39143 7.29367C1.90322 8.76524 1.90322 11.115 3.39143 12.5871C3.46447 12.6582 3.46447 12.8008 3.39143 12.8719C3.34294 12.9424 3.29445 12.9662 3.24536 12.9662Z" fill="#FFCC4B" />
                    <path d="M1.87913 14.0822C1.83004 14.0822 1.757 14.0583 1.73246 14.0111C0.634557 12.9431 0 11.4948 0 9.9761C0 8.45736 0.610012 7.00909 1.73246 5.94108C1.80549 5.87003 1.95216 5.87003 2.02519 5.94108C2.09823 6.01212 2.09823 6.1548 2.02519 6.22584C-0.0975769 8.29023 -0.0975769 11.6608 2.02519 13.7264C2.09823 13.7974 2.09823 13.9401 2.02519 14.0111C2.00065 14.0583 1.95216 14.0822 1.87913 14.0822Z" fill="#FFCC4B" /> </svg>
                  <p>Your address
                    <br> explained in your
                    <br> own voice</p>
                </div>
                <div class="features-pataa d-flex">
                  <svg xmlns="http://www.w3.org/2000/svg" width="30" height="30" viewBox="0 0 15 15" fill="none">
                    <path d="M11.4529 1.06754C11.4413 1.02211 11.428 0.977266 11.4123 0.933586C11.2169 0.389625 10.6979 0 10.0901 0C9.31539 0 8.68445 0.633068 8.68445 1.41174C8.68445 1.45367 8.68619 1.4956 8.69025 1.53695C8.69431 1.5818 8.70011 1.62664 8.70822 1.67032C8.71344 1.69769 8.71924 1.72448 8.7262 1.75128C8.78999 2.01044 8.92569 2.24224 9.11068 2.42278C9.13852 2.44957 9.16693 2.47578 9.19651 2.50024C9.20753 2.50956 9.2197 2.5183 9.2313 2.52761C9.24058 2.5346 9.24928 2.54217 9.25856 2.54916L9.3612 2.7L9.45863 2.84269L9.9846 3.61554C10.0084 3.65048 10.0478 3.67145 10.0901 3.67145C10.1325 3.67145 10.1719 3.65048 10.1957 3.61554L10.7217 2.84269L10.7512 2.79959L10.9217 2.54916C10.9739 2.51072 11.0232 2.46821 11.069 2.42336C11.1351 2.35872 11.1949 2.28767 11.2476 2.21137C11.3422 2.07392 11.4129 1.91842 11.4541 1.75186C11.4605 1.72507 11.4668 1.69828 11.4715 1.6709C11.4871 1.58704 11.4953 1.50026 11.4953 1.41232C11.4953 1.29293 11.4808 1.17761 11.4529 1.06754ZM11.0684 1.45949C11.0684 1.46532 11.0679 1.47056 11.0673 1.47638C11.0667 1.48628 11.0661 1.49677 11.065 1.50667C11.0644 1.51366 11.0632 1.52065 11.0627 1.52822C11.0615 1.53637 11.0609 1.54511 11.0598 1.55326C11.0586 1.56141 11.0574 1.56898 11.0557 1.57714C11.0545 1.58413 11.0534 1.5917 11.0516 1.59869C11.0499 1.60742 11.0482 1.61616 11.0464 1.62431C11.0453 1.63014 11.0435 1.63654 11.0424 1.64237C11.04 1.65169 11.0377 1.661 11.0354 1.67032C11.0342 1.67498 11.0331 1.67964 11.0313 1.68372C11.0284 1.6942 11.025 1.70468 11.0221 1.71517C11.0215 1.7175 11.0203 1.71983 11.0197 1.72216C10.9925 1.80486 10.9542 1.8829 10.9072 1.95453C10.7617 2.17526 10.5291 2.33367 10.2589 2.38027C10.256 2.38085 10.2537 2.38143 10.2508 2.38201C10.2502 2.38201 10.2502 2.38201 10.2496 2.38201C10.198 2.39075 10.1447 2.39541 10.0901 2.39541C10.0362 2.39541 9.98286 2.39075 9.93125 2.3826C9.93067 2.3826 9.93009 2.3826 9.93009 2.3826C9.92661 2.38201 9.92313 2.38143 9.91965 2.38085C9.78859 2.35755 9.66681 2.30805 9.55895 2.23816C9.37454 2.11819 9.23246 1.93764 9.16171 1.72449C9.16055 1.72099 9.15939 1.71808 9.15823 1.71458C9.15533 1.70468 9.15243 1.69537 9.14953 1.68546C9.14837 1.68081 9.14664 1.67556 9.14548 1.67032C9.14548 1.66974 9.14548 1.66974 9.14548 1.66916C9.14316 1.66042 9.14084 1.65168 9.1391 1.64295C9.13736 1.63596 9.1362 1.62955 9.13446 1.62257C9.13272 1.61499 9.13098 1.60684 9.12982 1.59869C9.12808 1.59053 9.12692 1.58238 9.12576 1.57481C9.1246 1.56782 9.12344 1.56083 9.12228 1.55384C9.12112 1.54452 9.11996 1.53462 9.1188 1.5253C9.11822 1.51948 9.11706 1.51366 9.11648 1.50725C9.11532 1.4956 9.11474 1.48337 9.11358 1.47172C9.11358 1.46765 9.113 1.46415 9.113 1.46008C9.11242 1.44377 9.11184 1.42746 9.11184 1.41115C9.11184 1.37679 9.11416 1.34243 9.11764 1.30865C9.11822 1.30166 9.1188 1.29467 9.11938 1.28769C9.17621 0.833996 9.53981 0.476403 9.99504 0.43214C10.0264 0.429228 10.0588 0.427481 10.0913 0.427481C10.1197 0.427481 10.1481 0.429228 10.176 0.431558C10.5083 0.460096 10.7918 0.655199 10.9467 0.933586C11.0035 1.03551 11.0424 1.14907 11.0598 1.26963C11.0667 1.31622 11.0708 1.3634 11.0708 1.41174C11.0696 1.42746 11.069 1.44377 11.0684 1.45949Z" fill="#FFCC4B" />
                    <path d="M10.0904 0.897915C9.80801 0.897915 9.57953 1.12796 9.57953 1.41101C9.57953 1.50536 9.60504 1.59388 9.64912 1.66959C9.73784 1.8216 9.90196 1.9241 10.0904 1.9241C10.2789 1.9241 10.443 1.8216 10.5317 1.66959C10.5758 1.59388 10.6013 1.50536 10.6013 1.41101C10.6013 1.12796 10.3723 0.897915 10.0904 0.897915Z" fill="#FFCC4B" />
                    <path d="M3.28651 7.93876C2.57728 7.93876 2.00201 8.5165 2.00201 9.22878C2.00201 9.46581 2.0658 9.68829 2.17715 9.87932C2.39983 10.262 2.8133 10.5194 3.28651 10.5194C3.75971 10.5194 4.17319 10.262 4.39587 9.87932C4.50721 9.68829 4.571 9.46639 4.571 9.22878C4.571 8.5165 3.99632 7.93876 3.28651 7.93876Z" fill="#FFCC4B" />
                    <path d="M11.0021 6.45778C7.35214 5.20503 7.55337 3.79621 8.69347 2.69023C8.68187 2.68091 8.67027 2.67218 8.65867 2.66286C8.6291 2.6384 8.6001 2.61219 8.57284 2.5854C8.38785 2.40486 8.25216 2.17306 8.18837 1.91389C8.18199 1.8871 8.17561 1.86031 8.17039 1.83294C8.16227 1.78926 8.15647 1.74441 8.15241 1.69957C6.69974 2.49687 4.9316 3.70361 4.61787 4.97848C6.41791 5.54632 7.72328 7.2347 7.72328 9.23C7.72328 10.0494 7.50234 10.8165 7.11786 11.4757C6.66321 12.2561 5.97892 12.8857 5.15835 13.2701C4.51465 13.7826 3.84892 14.2241 3.3009 14.5607H12.4518C13.6755 12.8065 16.2108 8.24574 11.0021 6.45778ZM6.45966 5.0175C6.42197 5.02449 6.38543 5.00003 6.37847 4.96217C6.37847 4.96101 6.37789 4.96043 6.37789 4.95926V4.95868C6.35586 4.80376 6.36282 4.64593 6.39181 4.49509C6.39819 4.46247 6.42951 4.44151 6.4614 4.44791C6.49272 4.45374 6.51359 4.48402 6.50895 4.51547C6.48808 4.65641 6.48866 4.7991 6.51475 4.93596C6.52171 4.97382 6.49735 5.00993 6.45966 5.0175ZM6.82848 3.63022C6.81108 3.61916 6.80645 3.59586 6.81746 3.57839C6.81746 3.57781 6.81804 3.57723 6.81862 3.57723C6.90561 3.4555 6.99956 3.34019 7.09814 3.22895C7.108 3.21789 7.12539 3.21672 7.13641 3.22662C7.14743 3.23652 7.14859 3.25283 7.13931 3.26448C7.04653 3.37863 6.95954 3.49686 6.87951 3.61916C6.8685 3.63663 6.84588 3.64129 6.82848 3.63022ZM7.35272 6.15784C7.3156 6.20035 7.25123 6.20501 7.2089 6.16774C7.20774 6.16658 7.20658 6.16541 7.20542 6.16483L6.88241 5.85499C6.84588 5.82005 6.84414 5.76123 6.87951 5.72453C6.91373 5.68901 6.9694 5.68668 7.00593 5.71871L7.00999 5.7222L7.33938 6.01107L7.34286 6.01399C7.38519 6.05068 7.38983 6.11532 7.35272 6.15784ZM10.0064 8.55208C10.0934 8.50025 10.2053 8.52762 10.2604 8.61207C10.345 8.74253 10.4222 8.87881 10.49 9.02092V9.0215C10.5376 9.12109 10.4958 9.2399 10.3967 9.28766C10.2975 9.33541 10.1792 9.29348 10.1316 9.19389C10.1305 9.19156 10.1287 9.18807 10.1282 9.18574C10.0742 9.05819 10.011 8.93356 9.94027 8.81242V8.81183C9.88692 8.72156 9.91649 8.60508 10.0064 8.55208ZM9.04721 7.51658C9.10636 7.45717 9.20204 7.45543 9.26293 7.51134L9.59696 7.8171C9.66481 7.87941 9.67003 7.98483 9.60798 8.05355C9.54593 8.12169 9.44097 8.12693 9.37254 8.06462C9.3708 8.06287 9.36906 8.0617 9.36732 8.05996L9.3592 8.0518L9.05301 7.74546L9.04663 7.73905C8.98632 7.67732 8.98632 7.57831 9.04721 7.51658ZM7.82534 2.5522C7.8236 2.55046 7.8236 2.54696 7.82592 2.54521H7.8265L7.99816 2.41476L7.83288 2.5522C7.82998 2.55395 7.82708 2.55395 7.82534 2.5522ZM7.95002 6.64123C7.99236 6.5894 8.06775 6.58066 8.12052 6.62027L8.47542 6.88584C8.53457 6.9301 8.54733 7.01455 8.50268 7.07454C8.4586 7.13394 8.37452 7.14675 8.31479 7.10191C8.31305 7.10074 8.31189 7.09958 8.31015 7.09841L8.30899 7.09783L7.96684 6.81653C7.91407 6.77285 7.90653 6.69423 7.95002 6.64123ZM8.96776 14.0645L8.79959 14.2258C8.67085 14.3499 8.46614 14.3452 8.34262 14.2153C8.2191 14.086 8.22374 13.8805 8.35306 13.7564C8.35596 13.7535 8.35944 13.7506 8.36292 13.7477L8.37974 13.7325L8.52819 13.6021L8.53863 13.5928C8.67085 13.4769 8.8715 13.4903 8.98748 13.6225C9.0994 13.7523 9.08954 13.9469 8.96776 14.0645ZM9.92055 12.9102L9.65031 13.2841C9.55405 13.4169 9.36906 13.4466 9.23742 13.3499C9.1052 13.2532 9.07562 13.0674 9.17189 12.9352C9.17421 12.9317 9.17653 12.9288 9.17943 12.9253L9.19045 12.9113L9.45546 12.5776L9.46648 12.5637C9.56449 12.4396 9.74426 12.4198 9.86778 12.5182C9.98724 12.6137 10.0093 12.7873 9.92055 12.9102ZM10.6089 11.5666C10.5584 11.7151 10.4999 11.8607 10.4355 12.0022V12.0028C10.3752 12.1356 10.2186 12.1944 10.0864 12.1338C9.95418 12.0733 9.89561 11.916 9.95592 11.7832C9.95766 11.7797 9.9594 11.7757 9.96114 11.7728C10.0249 11.6481 10.0823 11.5212 10.1334 11.3919V11.3913C10.1844 11.2602 10.3317 11.1962 10.4622 11.2474C10.588 11.2975 10.6524 11.4385 10.6089 11.5666ZM10.8113 10.5194V10.5206C10.8066 10.6487 10.6994 10.7489 10.5718 10.7442C10.4442 10.7396 10.3445 10.6318 10.3491 10.5037C10.3491 10.5002 10.3497 10.4961 10.3497 10.4932C10.3607 10.3575 10.3613 10.2212 10.3503 10.0867V10.0861C10.3404 9.96382 10.4309 9.85666 10.5526 9.84676C10.671 9.83686 10.7748 9.92305 10.7898 10.0401C10.8101 10.1985 10.8171 10.3593 10.8113 10.5194Z" fill="#5B7ABC" />
                    <path d="M3.28634 5.97515C1.47413 5.97515 0 7.45561 0 9.2756C0 9.48236 0.019137 9.68445 0.0556711 9.88072C0.0672693 9.9442 0.081767 10.0071 0.0974245 10.07C0.247041 10.6769 0.56425 11.2179 0.996861 11.6401C1.06123 11.703 1.1285 11.7636 1.19809 11.8213C1.24506 11.8603 1.29319 11.8981 1.34249 11.9348L1.58257 12.2878L1.80989 12.6221L3.03988 14.4293C3.09555 14.5114 3.18775 14.5597 3.28634 14.5597C3.38492 14.5597 3.47713 14.5108 3.5328 14.4293L4.76278 12.6221L4.83179 12.5207L5.23077 11.9343C5.35255 11.844 5.46737 11.7456 5.57581 11.6396C5.73065 11.4887 5.87041 11.3227 5.99335 11.1439C6.21429 10.8225 6.37956 10.4596 6.47583 10.0694C6.49149 10.0071 6.5054 9.9442 6.517 9.88014C6.55354 9.68387 6.57267 9.48177 6.57267 9.27502C6.57267 7.45561 5.09855 5.97515 3.28634 5.97515ZM5.45925 10.0024C5.39488 10.1958 5.30616 10.3781 5.19597 10.5452C4.85499 11.0618 4.31219 11.4311 3.68067 11.5411C3.6743 11.5423 3.66792 11.5435 3.66154 11.5446C3.66096 11.5446 3.6598 11.5446 3.65922 11.5446C3.53802 11.5644 3.41392 11.5755 3.28692 11.5755C3.1605 11.5755 3.0364 11.565 2.9152 11.5446C2.91404 11.5446 2.91288 11.5446 2.91172 11.5441C2.9036 11.5429 2.89548 11.5411 2.88736 11.5394C2.05519 11.392 1.37844 10.7945 1.11516 10.0054C1.11284 9.99778 1.10994 9.99021 1.10762 9.98264C1.10008 9.95992 1.09371 9.93721 1.08675 9.91392C1.08327 9.90227 1.07979 9.89062 1.07689 9.87897C1.07689 9.87839 1.07631 9.87722 1.07631 9.87664C1.07109 9.85626 1.06587 9.83587 1.06065 9.81549C1.05659 9.79976 1.05311 9.78404 1.04963 9.76832C1.04557 9.75026 1.04151 9.73162 1.03803 9.71299C1.03456 9.69435 1.03108 9.67513 1.02818 9.65649C1.02528 9.64019 1.02296 9.62388 1.02006 9.60699C1.01658 9.58486 1.01426 9.56273 1.01136 9.5406C1.00962 9.52662 1.00788 9.51264 1.00672 9.49866C1.00382 9.47129 1.00208 9.44334 1.00034 9.41538C0.999761 9.40606 0.999181 9.39733 0.998601 9.38801C0.996861 9.35015 0.995701 9.31171 0.995701 9.27386C0.995701 9.17601 1.00266 9.07992 1.01426 8.98557C1.14648 7.92502 1.9972 7.08928 3.06133 6.98503C3.13498 6.97804 3.20979 6.97396 3.28576 6.97396C3.35245 6.97396 3.41798 6.97746 3.48351 6.98328C4.65608 7.08404 5.57639 8.0712 5.57639 9.27444C5.57639 9.3123 5.57523 9.34957 5.57349 9.38684C5.57291 9.40024 5.57175 9.41305 5.57059 9.42645C5.56885 9.45033 5.56769 9.47362 5.56537 9.49692C5.56363 9.51381 5.56189 9.53011 5.55958 9.54642C5.55726 9.56622 5.55494 9.58544 5.55204 9.60466C5.54914 9.6233 5.54624 9.64193 5.54334 9.65999C5.54044 9.67688 5.53754 9.69377 5.53464 9.71008C5.53058 9.73046 5.52652 9.75026 5.52246 9.77064C5.51956 9.78462 5.51608 9.7986 5.5126 9.81258C5.50738 9.83471 5.50158 9.85684 5.49578 9.87839C5.49289 9.88887 5.48999 9.89936 5.48651 9.91042C5.47955 9.93488 5.47201 9.95934 5.46447 9.9838C5.46331 9.99137 5.46157 9.99662 5.45925 10.0024Z" fill="#FFCC4B" /> </svg>
                  <p>Suggested routes
                    <br> from landmarks</p>
                </div>
                <div class="features-pataa d-flex">
                  <svg xmlns="http://www.w3.org/2000/svg" width="32" height="30" viewBox="0 0 16 15" fill="none">
                    <path d="M14.9951 0.457602H9.84607V3.87446H14.9951V0.457602Z" fill="white" />
                    <path d="M7.69582 9.50228H7.12678C6.98683 9.50228 6.87329 9.61582 6.87329 9.75577V10.1981C6.87329 10.2324 6.90102 10.2614 6.93666 10.2614H7.69582C7.73015 10.2614 7.75919 10.2337 7.75919 10.1981V9.56565C7.75919 9.53133 7.73147 9.50228 7.69582 9.50228Z" fill="#5B7ABC" />
                    <path d="M9.15055 11.2727V10.8304C9.15055 10.7961 9.12282 10.767 9.08718 10.767H8.32802C8.29369 10.767 8.26465 10.7948 8.26465 10.8304V11.4628C8.26465 11.4971 8.29237 11.5262 8.32802 11.5262H8.89706C9.03701 11.5249 9.15055 11.4126 9.15055 11.2727Z" fill="#5B7ABC" />
                    <path d="M4.8518 9.50228H2.82783C2.68788 9.50228 2.57434 9.61582 2.57434 9.75577V14.4652C2.57434 14.518 2.61659 14.5602 2.6694 14.5602H5.00892C5.06173 14.5602 5.10398 14.518 5.10398 14.4652V9.75577C5.10398 9.61582 4.99043 9.50228 4.8518 9.50228ZM4.09265 11.5249C4.09265 11.385 4.20619 11.2714 4.34614 11.2714C4.48609 11.2714 4.59963 11.385 4.59963 11.5249V11.7784C4.59963 11.9184 4.48609 12.0319 4.34614 12.0319C4.20619 12.0319 4.09265 11.9184 4.09265 11.7784V11.5249Z" fill="#5B7ABC" />
                    <path d="M9.15055 9.75577C9.15055 9.61582 9.03701 9.50228 8.89706 9.50228H8.32802C8.29369 9.50228 8.26465 9.53001 8.26465 9.56565V10.1981C8.26465 10.2324 8.29237 10.2614 8.32802 10.2614H9.08718C9.1215 10.2614 9.15055 10.2337 9.15055 10.1981V9.75577Z" fill="#5B7ABC" />
                    <path d="M7.12678 11.5255H7.69582C7.73015 11.5255 7.75919 11.4978 7.75919 11.4621V10.8297C7.75919 10.7954 7.73147 10.7663 7.69582 10.7663H6.93666C6.90234 10.7663 6.87329 10.7941 6.87329 10.8297V11.272C6.87461 11.4133 6.98815 11.5255 7.12678 11.5255Z" fill="#5B7ABC" />
                    <path d="M6.49327 2.54346C6.03118 2.28733 5.45158 2.33222 5.03305 2.67945L0.0912896 6.76964C-0.0169724 6.85942 -0.0301751 7.01917 0.0582829 7.12611C0.212754 7.31359 0.257643 7.39941 0.390991 7.41129C0.458324 7.41789 0.524338 7.39677 0.575828 7.35452C1.01548 6.99145 0.202192 7.66346 5.37896 3.37787C5.65886 3.1455 6.0655 3.1455 6.34672 3.37787C6.37841 3.40428 6.40877 3.42936 6.43914 3.45445C6.43782 3.39899 6.43518 3.34354 6.43518 3.28809C6.43518 3.0346 6.45498 2.78639 6.49327 2.54346Z" fill="#5B7ABC" />
                    <path d="M6.52006 4.17689C6.3603 4.04486 6.19659 3.90887 6.02496 3.76628C5.93122 3.68971 5.79655 3.68971 5.70281 3.76628C1.52548 7.22539 0.949844 7.70464 0.844223 7.78518C0.819137 7.80366 0.805935 7.83139 0.805935 7.86176V14.0551H0.308194C0.173526 14.0551 0.0560222 14.1568 0.0467803 14.2915C0.0375384 14.4393 0.153722 14.5608 0.298952 14.5608H1.97437C2.02718 14.5608 2.06943 14.5185 2.06943 14.4657V9.75634C2.06943 9.33782 2.40874 8.99719 2.82859 8.99719H4.85124C5.26976 8.99719 5.61039 9.3365 5.61039 9.75634V14.4657C5.61039 14.5185 5.65264 14.5608 5.70545 14.5608H11.4262C11.5714 14.5608 11.6876 14.438 11.6783 14.2915C11.6691 14.1568 11.5516 14.0551 11.4169 14.0551H10.9192V7.99774C8.72359 7.89212 6.92274 6.28404 6.52006 4.17689ZM9.65702 11.2733C9.65702 11.6919 9.31639 12.0325 8.89786 12.0325H7.12738C6.70886 12.0325 6.36823 11.6919 6.36823 11.2733V9.75634C6.36823 9.33782 6.70886 8.99719 7.12738 8.99719H8.89786C9.31639 8.99719 9.65702 9.33782 9.65702 9.75634V11.2733Z" fill="#5B7ABC" />
                    <path d="M10.0468 5.22975C9.56889 5.22975 9.14244 4.92345 8.98797 4.46796L8.97741 4.43231C8.94044 4.31217 8.92592 4.21051 8.92592 4.10885V2.07167L8.20109 4.49172C8.10735 4.8482 8.31992 5.21655 8.67639 5.31557L13.2973 6.55266C13.3554 6.56719 13.4122 6.57511 13.469 6.57511C13.766 6.57511 14.038 6.37707 14.1146 6.08661L14.3839 5.23108H10.0468V5.22975Z" fill="#FFCC4B" />
                    <path d="M10.8679 2.09123C11.1979 2.09123 11.4659 1.82322 11.4659 1.49315C11.4659 1.16309 11.1979 0.895071 10.8679 0.895071C10.5378 0.895071 10.2698 1.16309 10.2698 1.49315C10.2698 1.82322 10.5391 2.09123 10.8679 2.09123Z" fill="#FFCC4B" />
                    <path d="M14.6029 0H10.1206C9.70864 0 9.37329 0.335348 9.37329 0.747272V4.03474C9.37329 4.44666 9.70864 4.78201 10.1206 4.78201H14.6029C15.0148 4.78201 15.3501 4.44666 15.3501 4.03474V0.747272C15.3501 0.335348 15.0148 0 14.6029 0ZM10.1206 0.598082H14.6029C14.6847 0.598082 14.7521 0.665415 14.7521 0.747272V2.86894L13.8081 1.76784C13.7077 1.65034 13.5625 1.58828 13.4067 1.58432C13.2522 1.58564 13.107 1.6543 13.008 1.77312L11.8976 3.10527L11.5359 2.74484C11.3312 2.5402 10.9985 2.5402 10.7952 2.74484L9.97005 3.56869V0.747272C9.97137 0.664095 10.0387 0.598082 10.1206 0.598082Z" fill="#FFCC4B" /> </svg>
                  <p>Address and photos
                    <br> of your property</p>
                </div>
              </div>
            </div>
            <div class="create-pataa">
              <p>Create your Pataa now & start sharing with</p>
              <div class="create-pataa-box  mt-3 mx-auto  text-center flex-wrap   w-100">
                <div class="create-pataa-features">
                  <svg xmlns="http://www.w3.org/2000/svg" width="43" height="43" viewBox="0 0 43 43" fill="none">
                    <circle cx="21.5" cy="21.5" r="21" fill="white" stroke="#565C66" />
                    <g clip-path="url(#clip0_2_219)">
                      <path d="M17.7178 32C16.2475 31.6073 14.7772 31.2124 13.3058 30.823C12.2416 30.5414 11.9103 30.1146 12.0207 29.019C12.3728 25.5221 14.2319 23.0053 17.5154 21.4587C17.9675 21.2464 18.3241 21.0154 18.5358 20.5732C18.7314 20.1662 18.9914 20.0749 19.3688 20.4324C19.9095 20.945 20.4824 21.4268 21.0887 21.9647C20.6653 22.0703 20.3191 22.1572 19.8048 22.2848C21.4649 22.6071 22.9548 22.9393 24.4607 23.1692C25.1694 23.277 25.9103 23.1879 26.6363 23.1879C26.6443 23.1032 26.6524 23.0185 26.6593 22.9338C25.0785 22.6236 23.4989 22.3134 21.817 21.9834C22.4865 21.3839 23.0813 20.824 23.7198 20.3147C23.8061 20.2454 24.2399 20.3785 24.2974 20.5072C24.5539 21.0726 25.0728 21.2585 25.587 21.5071C28.79 23.0592 30.5996 25.5474 30.9781 28.9684C31.0978 30.0563 30.7239 30.5733 29.6217 30.8648C28.2757 31.2201 26.9227 31.5534 25.5744 31.8977C25.4835 31.9208 25.3995 31.9659 25.3121 32.0011C25.0049 32.0011 24.6989 32.0011 24.3917 32.0011C24.0006 31.7316 23.6082 31.4621 23.1389 31.1387C22.0988 31.5358 20.9369 31.527 19.9325 31.142C19.4309 31.4753 19.034 31.7382 18.6382 32.0011C18.331 32 18.0239 32 17.7178 32ZM21.2866 27.7485C21.2866 26.9246 21.2693 26.1007 21.2935 25.2768C21.3085 24.7906 21.1037 24.5288 20.6101 24.4232C19.1548 24.1119 17.7017 23.7907 16.251 23.4607C15.7862 23.3551 15.6148 23.519 15.6182 23.9557C15.6274 25.1635 15.6332 26.3724 15.6136 27.5802C15.6079 27.908 15.7436 28.0191 16.052 28.0906C16.794 28.2633 17.5303 28.4624 18.2643 28.6692C18.988 28.8727 19.6046 29.2885 19.7266 30.0013C19.829 30.5964 20.1867 30.6635 20.6389 30.7603C21.0784 30.8549 21.297 30.7317 21.29 30.2741C21.2774 29.4326 21.2854 28.5911 21.2866 27.7485ZM23.935 24.1108C23.3586 24.2329 22.8742 24.3363 22.3899 24.4375C21.9504 24.5288 21.7502 24.7807 21.7525 25.2174C21.7617 26.8839 21.7445 28.5504 21.7721 30.2158C21.7755 30.4094 22.0402 30.7779 22.1161 30.7625C22.5049 30.6833 23.1066 30.8736 23.2194 30.3368C23.4253 29.3622 24.0604 28.8573 24.9946 28.6043C25.694 28.4151 26.4027 28.2578 27.0942 28.0477C27.2403 28.0037 27.4313 27.7958 27.4336 27.6594C27.46 26.4142 27.4485 25.169 27.4485 23.9238C27.4485 23.5223 27.261 23.3485 26.8307 23.453C26.336 23.5729 25.8379 23.6829 25.3155 23.8028C25.3155 24.3484 25.3155 24.8577 25.3155 25.4132C24.8588 25.5298 24.4239 25.6409 23.9327 25.7663C23.935 25.191 23.935 24.6817 23.935 24.1108ZM23.7555 23.5751C21.9401 23.2319 20.2408 22.8447 18.5186 22.617C17.8386 22.5268 17.1069 22.7908 16.3994 22.8931C16.4063 22.9635 16.4132 23.0339 16.4213 23.1032C18.8234 23.3727 21.1451 24.5717 23.7555 23.5751Z" fill="#565C66" />
                      <path d="M21.6295 10C21.9033 10.1386 22.1633 10.3641 22.4509 10.4015C24.8473 10.7161 25.8586 11.7996 25.7079 14.5573C25.7033 14.6475 25.6872 14.7377 25.6768 14.8213C26.6029 15.3834 26.6697 16.1985 25.877 16.8893C25.7332 17.0147 25.6262 17.2006 25.556 17.3777C24.8979 19.0387 23.3172 20.1134 21.5064 20.1167C19.6829 20.12 18.132 19.0772 17.4475 17.3964C17.3888 17.2512 17.3129 17.0851 17.1921 16.9938C16.1532 16.2139 16.1808 15.4373 17.3117 14.8136C17.3117 14.2471 17.2554 13.6586 17.3221 13.0844C17.5292 11.3156 19.0685 10.6776 20.4077 10.4411C20.7309 10.385 21.0623 10.3806 21.1693 10C21.3234 10 21.4764 10 21.6295 10ZM21.4718 13.6938C20.3547 13.6971 19.3113 13.9512 18.3897 14.5705C17.9319 14.8785 17.9238 15.2503 18.4335 15.4296C18.8016 15.5594 19.3205 15.5803 19.6668 15.4296C20.9771 14.8598 22.2358 14.8169 23.5208 15.4648C23.7268 15.5693 24.0213 15.6507 24.2238 15.5891C24.4838 15.5099 24.7656 15.313 24.8899 15.0908C24.9474 14.9885 24.7012 14.6398 24.5125 14.5166C23.5991 13.9281 22.5659 13.6938 21.4718 13.6938ZM19.4068 17.5999C19.5241 18.7472 20.4445 19.5194 21.5386 19.4479C22.6016 19.3786 23.4219 18.5657 23.3885 17.5999C22.0735 17.5999 20.7586 17.5999 19.4068 17.5999Z" fill="#565C66" /> </g>
                    <defs>
                      <clipPath id="clip0_2_219">
                        <rect width="19" height="22" fill="white" transform="translate(12 10)" /> </clipPath>
                    </defs>
                  </svg>
                  <p>Delivery Guys</p>
                </div>
                <div class="create-pataa-features">
                  <svg xmlns="http://www.w3.org/2000/svg" width="43" height="43" viewBox="0 0 43 43" fill="none">
                    <circle cx="21.5" cy="21.5" r="21" fill="white" stroke="#565C66" />
                    <g clip-path="url(#clip0_2_244)">
                      <path d="M25.3406 22.8005C25.3974 22.87 25.4555 22.9396 25.5135 23.0105C25.9432 23.5387 26.0219 24.1151 25.7303 24.7382C25.4348 25.3708 24.9639 25.8188 24.3497 26.109C24.2748 26.1451 24.1987 26.1772 24.1239 26.2106C24.1329 26.2333 24.1419 26.2561 24.151 26.2788C24.44 26.1544 24.7471 26.0648 25.0116 25.8977C25.2916 25.7211 25.5587 25.4992 25.7781 25.2464C25.9923 25.0017 26.1406 24.6941 26.3329 24.3905C26.8426 24.5604 27.3742 24.7356 27.9045 24.9161C28.4864 25.114 29.0735 25.2986 29.6464 25.5206C31.0116 26.0501 31.8039 27.1079 31.9329 28.5789C32.0452 29.8641 31.9793 31.1652 31.9793 32.4597C31.9793 32.7847 31.7716 32.9719 31.4555 32.9933C31.3729 32.9987 31.289 32.996 31.2052 32.996C25.089 32.996 18.9729 32.996 12.8568 32.996C12.1058 32.996 12 32.889 12.0026 32.1161C12.0052 31.0262 11.9858 29.9336 12.0181 28.845C12.0645 27.3032 12.9716 26.018 14.369 25.5058C15.3948 25.1301 16.4361 24.7971 17.471 24.4454C17.4981 24.436 17.529 24.436 17.5781 24.428C17.8464 25.0846 18.2761 25.5995 18.8877 25.9284C19.1497 26.0688 19.4361 26.1625 19.7252 26.244C19.3019 26.0381 18.911 25.7907 18.5897 25.4376C18.3213 25.1421 18.1213 24.8051 18.0064 24.4146C17.8981 24.0402 17.9419 23.6871 18.1174 23.3461C18.1484 23.2859 18.1781 23.2231 18.2129 23.1522C18.0013 23.0947 17.7987 23.0626 17.6116 22.9864C17.0064 22.7403 16.5742 22.287 16.2877 21.6919C15.7135 20.4977 15.6516 19.258 16.2013 18.0585C16.7639 16.8295 17.1135 15.5377 17.4761 14.2432C17.6761 13.5304 17.9045 12.819 18.2 12.1437C18.76 10.8679 19.7484 10.1752 21.0981 10.0361C22.3561 9.90639 23.5497 10.0642 24.5923 10.8746C25.4723 11.5593 26.0013 12.5061 26.2348 13.592C26.5264 14.9493 26.9264 16.2705 27.2955 17.6025C27.5819 18.6389 27.6452 19.7047 27.3742 20.7652C27.1148 21.7828 26.4981 22.4435 25.5045 22.7096C25.4606 22.7216 25.4181 22.7363 25.3755 22.7537C25.3677 22.7631 25.36 22.7791 25.3406 22.8005ZM25.4723 17.5463C25.3948 17.4514 25.3381 17.3898 25.2903 17.323C24.9342 16.8282 24.7226 16.2732 24.6452 15.6621C24.6129 15.4107 24.5019 15.2983 24.2581 15.3037C24.1458 15.3064 24.0335 15.3304 23.9239 15.3598C23.5742 15.4548 23.231 15.6006 22.8748 15.6487C22.0542 15.761 21.3084 15.4762 20.5948 15.0897C20.3768 14.9707 20.1664 14.8356 19.9574 14.7099C19.7587 15.0362 19.6 15.3732 19.3729 15.65C18.9213 16.2023 18.6723 16.8148 18.6981 17.5423C18.7045 17.7108 18.6219 17.7964 18.4619 17.8352C18.3032 17.5423 18.1484 17.2575 17.9974 16.978C17.6787 17.0849 17.6348 17.1572 17.6761 17.4607C17.7174 17.7629 17.7613 18.0665 17.7935 18.3701C17.8168 18.5867 17.9097 18.7258 18.1252 18.7472C18.2916 18.7646 18.369 18.8528 18.4129 19.02C18.6774 20.0363 19.1781 20.9243 19.8026 21.7454C20.8103 23.0693 22.6439 23.1228 23.6723 21.8617C24.3548 21.0246 24.8826 20.1019 25.1664 19.0401C25.2155 18.8542 25.3097 18.782 25.4813 18.7311C25.5923 18.699 25.7394 18.584 25.7613 18.4811C25.84 18.1066 25.8774 17.7228 25.9226 17.3417C25.9394 17.1973 25.8864 17.0876 25.7303 17.0381C25.6852 17.1277 25.6477 17.204 25.609 17.2789C25.5729 17.3537 25.5329 17.43 25.4723 17.5463ZM24.2271 22.2041C22.8323 23.6483 21.3613 23.7834 19.7548 22.624C19.7548 23.1856 19.7535 23.7232 19.7574 24.2595C19.7574 24.3103 19.7948 24.3611 19.8181 24.4106C20.1794 25.1902 20.791 25.5861 21.609 25.6556C22.3535 25.7198 23.0774 25.6369 23.649 25.0873C23.889 24.8559 24.1626 24.5403 24.2026 24.2327C24.2852 23.5801 24.2271 22.9075 24.2271 22.2041Z" fill="#565C66" /> </g>
                    <defs>
                      <clipPath id="clip0_2_244">
                        <rect width="20" height="23" fill="white" transform="translate(12 10)" /> </clipPath>
                    </defs>
                  </svg>
                  <p>Visitors</p>
                </div>
                <div class="create-pataa-features">
                  <svg xmlns="http://www.w3.org/2000/svg" width="43" height="43" viewBox="0 0 43 43" fill="none">
                    <circle cx="21.5" cy="21.5" r="21" fill="white" stroke="#565C66" />
                    <path d="M18.4646 24.9127C18.5858 25.3129 18.6857 25.6735 18.81 26.0256C18.8345 26.0943 18.95 26.1673 19.0304 26.1752C19.2376 26.1965 19.448 26.1825 19.6577 26.1825C22.3364 26.1825 25.0151 26.1825 27.6938 26.1825C27.788 26.1825 27.8828 26.1776 27.9764 26.1868C28.2614 26.2153 28.4831 26.4263 28.5183 26.6945C28.5559 26.9828 28.3965 27.2528 28.1126 27.3385C27.9864 27.3768 27.8451 27.3817 27.7108 27.3823C24.8123 27.3841 21.9138 27.3841 19.0153 27.3835C18.2417 27.3835 17.8254 27.0874 17.61 26.3795C17.1674 24.9261 16.7354 23.4697 16.287 22.0175C15.5486 19.6258 14.8007 17.2359 14.0548 14.846C13.9091 14.379 13.6673 14.2111 13.1568 14.2099C12.4247 14.2081 11.6919 14.2105 10.9598 14.2087C10.4989 14.2069 10.2276 13.9752 10.2345 13.5939C10.2414 13.2302 10.5108 13.0052 10.9547 13.0034C11.7396 13.0004 12.5245 12.9973 13.3088 13.004C14.1716 13.0107 14.9345 13.5544 15.2007 14.3546C15.3608 14.8357 15.5191 15.3191 15.644 15.8092C15.7131 16.0799 15.8236 16.1723 16.1275 16.1717C20.5223 16.1595 24.9171 16.1632 29.312 16.1632C30.186 16.1632 30.5232 16.6041 30.2714 17.4238C29.8312 18.8583 29.3886 20.2929 28.9465 21.7268C28.7173 22.4718 28.485 23.2155 28.2583 23.961C28.0825 24.5375 27.5663 24.9109 26.9202 24.9115C24.2522 24.9134 21.5835 24.9127 18.9155 24.9127C18.7799 24.9127 18.6442 24.9127 18.4646 24.9127ZM22.2114 20.541C22.2133 20.541 22.2146 20.541 22.2165 20.541C22.2165 21.32 22.2146 22.099 22.2177 22.878C22.219 23.1243 22.3182 23.3189 22.592 23.3614C22.8406 23.4004 23.0554 23.2143 23.1018 22.9339C23.1232 22.805 23.1301 22.6724 23.1295 22.5417C23.1269 21.9871 23.115 21.4325 23.1131 20.8779C23.11 20.0077 23.1119 19.1375 23.1131 18.2673C23.1138 18.0252 23.0447 17.8203 22.7841 17.7418C22.4708 17.6476 22.2183 17.861 22.214 18.2338C22.2058 19.0031 22.2114 19.7717 22.2114 20.541ZM20.1826 22.8093C20.1242 22.4882 20.0464 22.1014 19.9848 21.7128C19.8002 20.544 19.625 19.374 19.4385 18.2058C19.3802 17.8385 19.1805 17.6798 18.8891 17.7352C18.6229 17.7856 18.5036 18.0161 18.5569 18.356C18.6794 19.135 18.8 19.9146 18.9167 20.6949C19.0273 21.4337 19.1265 22.1744 19.2408 22.9127C19.2891 23.2258 19.4787 23.3858 19.7274 23.3584C20.015 23.3262 20.1877 23.1443 20.1826 22.8093ZM26.7683 18.2551C26.7814 17.9456 26.637 17.7564 26.3859 17.7291C26.119 17.6999 25.9275 17.8543 25.881 18.1529C25.6418 19.7036 25.4032 21.2543 25.1746 22.8062C25.157 22.9248 25.1777 23.1054 25.2562 23.1675C25.3768 23.2629 25.567 23.3316 25.7209 23.3201C25.9582 23.3025 26.0505 23.106 26.0807 22.8865C26.1736 22.2151 26.2672 21.5438 26.367 20.8736C26.4989 19.9919 26.637 19.1113 26.7683 18.2551Z" fill="#565C66" />
                    <path d="M26.5622 27.9995C27.4231 27.9977 28.1232 28.6679 28.1257 29.4961C28.1282 30.3201 27.4237 31 26.5691 31C25.7057 30.9994 25.015 30.3359 25.0113 29.5028C25.0069 28.6727 25.7001 28.0014 26.5622 27.9995Z" fill="#565C66" />
                    <path d="M18.6724 30.9994C17.821 30.9836 17.1422 30.2909 17.1617 29.4566C17.1811 28.6338 17.9032 27.9758 18.761 27.9989C19.6068 28.022 20.2874 28.7019 20.2755 29.5119C20.2636 30.3566 19.5534 31.0152 18.6724 30.9994Z" fill="#565C66" /> </svg>
                  <p>Online Shops</p>
                </div>
              </div>
            </div>
            <div class="pataa-points">
              <p>Millions of Indians are using Pataa for </p>
              <ul>
                <li>
                  <p>Faster checkout on e-commerce</p>
                </li>
                <li>
                  <p>No more explaining address on calls</p>
                </li>
                <li>
                  <p>Hassle-free deliveries</p>
                </li>
                <li>
                  <p>Saving fuel & reducing pollution</p>
                </li>
              </ul>
            </div>
          </div>
        </div>
        <div class="pataa-footer d-flex justify-content-between align-items-center">
          <div>
            <p class="footer-title">Don’t have a Pataa yet ?</p>
            <p class="m-0 pataa-examples">e.g. <span>^KUMAR100</span>, <span>^SINGH221</span></p>
          </div>
          <button type="button" class="btn btn-footer createPataaBtn" id="">Create Pataa</button>
        </div>
		
      </div>
    </div>
  </div>
<!-- // What’s Pataa Popup -->
	
<!-- Create Pataa Popup -->

	<div class="create-pataa-popup" id="createPataa" style="display:none;">
		<button type="button" class="close" style="opacity: 0 !important;" data-dismiss="modal" aria-label="Close" id="close-btn">
			<span aria-hidden="true">&times;</span>
		</button>
          <!-- 16:9 aspect ratio -->
		<div id="create-pataa-content" class=""> <!-- embed-responsive embed-responsive-16by9 -->
		
		<script>
			
			function make_blank()
			{

				//alert(1);
				//document.getElementById("pataacode").value = "";
				var element = document.getElementById("pataa-unavailable");
				element.style.display = "none";
				var element1 = document.getElementById("pataa-available");
				element1.style.display = "none";
				var element2 = document.getElementById("autofill");
				element2.style.display = "block";
				var element3 = document.getElementById("main-code");
				element3.classList.remove("pataa-not-found");
				element3.classList.remove("succ-msg-sec");
				
				document.getElementById("err-msg").style.display = "none";    
            	document.getElementById("succ-msg").style.display = "none";
				document.getElementById("first-msg").style.display = "block";
				
			}
		</script>
	</div>
	</div>
<!-- // Create Pataa Popup -->
';
echo apply_filters( 'lpac_map_markup', $markup, $user_id );

	}

	public function autofill_on_checkout()
	{
		$user_id = (int) get_current_user_id();
		 $dir=plugin_dir_url(__FILE__);
		if(get_option("demo-radio_1")==1){
		$type="services";
		$title = "";
		if(get_option("demo-radio")==1) { $type="services"; $title = "";} else { $type="delivery"; $title = "shipping";}
		
		$markup = '<div class="autofill-container">
			<div class="pataa-section">
				<div class="pataa-input-heading">AUTOFILL your '.$title.' address</div>
				<div class="main-pataa-code position-relative" id="main-code">
				
					<div class="pataa-code">
						<div class="logo-pataa">
						<img src='.$dir.'img/logo-input.svg style="width: 35px;max-width: 35px;" alt="">
						</div>
						<input id="pataacode" type="text" placeholder="Enter Pataa" maxlength="16" onfocus="this.placeholder = """ onfocus="focusFunction()" oninput="this.value = this.value.toUpperCase()">	
						<div class="pataa-examples">
				<img src='.$dir.'img/final.gif">
				</div>
						<button id="autofill" type="submit" class="auto-fill">
							<div class="d-flex align-items-center" style="justify-content: center;">
							<span id="add_text">Add Address</span>
							<svg id="autofill_icon" display="none" xmlns="http://www.w3.org/2000/svg" width="5" height="8" viewBox="0 0 5 8" fill="#181B21">
								<path d="M4.78385 3.56983C3.57349 2.4677 2.36362 1.36513 1.1557 0.261007C1.02435 0.140815 0.887893 0.0352593 0.700356 0C0.643195 0 0.586033 0 0.528872 0C0.496522 0.00953552 0.463928 0.019071 0.431577 0.0286066C0.229932 0.0878155 0.0939612 0.208894 0.0309624 0.392952C-0.0488199 0.626462 0.0302327 0.821164 0.214608 0.989033C1.29143 1.96986 2.36751 2.95135 3.44482 3.93174C3.46841 3.95303 3.50393 3.96345 3.53384 3.97897C3.49322 4.03109 3.46622 4.04661 3.44409 4.06679C2.64797 4.79171 1.85233 5.51708 1.0567 6.24244C0.774057 6.50012 0.491657 6.75847 0.208283 7.01548C0.0652591 7.14521 -0.0167124 7.29822 0.0034764 7.4845C0.02853 7.7149 0.162798 7.88011 0.399712 7.96083C0.651951 8.04665 0.878163 7.98833 1.06692 7.81647C2.31133 6.68285 3.55574 5.54923 4.79698 4.41273C4.86728 4.34842 4.92858 4.26482 4.96166 4.17988C5.05384 3.94438 4.97406 3.74302 4.78385 3.56983Z" fill="#181B21"></path>
							</svg>
						</button>
						<div class="pataa-available" id="pataa-available">
							<img src='.$dir.'img/right.svg" style="" alt="">
						</div>
						<div class="pataa-unavailable" id="pataa-unavailable">
							<img class="clearInput" src='.$dir.'img/close.svg" style="" alt="">
						</div>
					</div>
					<div class="create-pataas" id="err-msg" style="display:none;">
						<p>Please enter a valid pataa or <a href="javascript:void(0)"  class="createPataaBtn">Create now</a></p>
					</div>
					<div class="create-pataas" id="first-msg">
						<p >Or <a href="javascript:void(0)" class="createPataaBtn">click here</a> to save location on map for faster $type</p>
					</div>
					<div class="create-pataas" id="succ-msg" style="display:none;">
						<p ></p>
					</div>

				</div>
				<div class="text-right">
					<a href="javascript:void(0)" class="btn-what-pataa video-btn">What’s Pataa? <img src='.$dir.'img/info.svg" alt="" style="width: 17px;"></a>
				</div>
			</div>
		
	</div>';
			}
else
{
if(get_option("demo-radio")==1) { $type="services"; } else { $type="deliveries";}

	$markup = '
		<div class="button-parent"><button class="pataa-btn-black">
			<svg width="22" height="14" viewBox="0 0 22 14" fill="none" xmlns="http://www.w3.org/2000/svg">
			<path d="M21.9609 14L11.3715 0L8.69885 3.51542L16.6156 14H21.9609Z" fill="#E39D02"></path>
			<path d="M0.757812 14L11.3472 0L14.0199 3.51542L6.10314 14H0.757812Z" fill="#FFC543"></path>
			</svg>
			
			<span id="address-button-text">SET DELIVERY LOCATION</span>
		
        <div class="pataa-inner-btn" id="btn-pataa-code" style="display:none;width:100%">
			<span style="justify-content:space-between!important;width:100%!important">
			<span>
			
			<p id="pataa-code-val"></p>
			</span>
			
			</span>
		</div>
		<span id="edit_icon" class="edit">
			<img class="arrow-move" src="https://assets.pataa.com/cpimages/arrow-right.svg" width="18" >
			</span>
</button>
<button id="autofill_1" hidden type="button" class="auto-fill"></button>
<input id="pataacode_1" type="hidden">
<input id="allow" type="hidden">
					<div class="pataa-address-box" id="err-msg" style="display:none;">
						<p class="button-text">Please enter a valid pataa or <a href="javascript:void(0)"  class="createPataaBtn">Create now</a></p>
					</div>
					<div class="pataa-address-box" id="first-msg">
						<p class="button-text">Click here to add address for faster '.$type.'</p>
					</div>
					<div class="pataa-address-box" id="succ-msg" style="display:none;">
						<p class="button-text"></p>
					</div>
    </div>
';
	
}
echo apply_filters( 'lpac_map_markup', $markup, $user_id );
	}

}
